HexWaveParameters class final

private:

Inheritance
Implemented types
Available extensions

Constructors

HexWaveParameters()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
half_height double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
peak_time double
getter/setter pair
reflect int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zero_wait double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited