insert_mode property

  1. @UnsignedChar()
int insert_mode
getter/setter pair

selection start and end point in characters; if equal, no selection. note that start may be less than or greater than end (e.g. when dragging the mouse, start is where the initial click was, and you can drag in either direction)

Implementation

@ffi.UnsignedChar()
external int insert_mode;