shareModeAsInt property
Set to whatever was passed in when the device was initialized.
Implementation
@ffi.UnsignedInt()
external int shareModeAsInt;
Set to whatever was passed in when the device was initialized.
@ffi.UnsignedInt()
external int shareModeAsInt;