UnnamedStruct$23 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct$23()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
pMainLoop Pointer<Void>
pa_mainloop
getter/setter pair
pPulseContext Pointer<Void>
pa_context
getter/setter pair
pStreamCapture Pointer<Void>
pa_stream
getter/setter pair
pStreamPlayback Pointer<Void>
pa_stream
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited