UnnamedStruct$38 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct$38()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags$1 int
Resource manager data source flags that were used when initializing the data buffer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pDataBufferNode Pointer<Void>
ma_resource_manager_data_buffer_node
getter/setter pair
pDoneFence Pointer<ma_fence>
Released if initialization of the decoder fails. Passed through to PAGE_DATA_BUFFER_NODE untouched if init is successful.
getter/setter pair
pDoneNotification Pointer<Void>
Signalled when the data buffer has been fully decoded. Will be passed through to MA_JOB_TYPE_RESOURCE_MANAGER_PAGE_DATA_BUFFER_NODE when decoding.
getter/setter pair
pFilePath Pointer<Char>
getter/setter pair
pFilePathW Pointer<WChar>
getter/setter pair
pInitFence Pointer<ma_fence>
Released when initialization of the decoder is complete.
getter/setter pair
pInitNotification Pointer<Void>
Signalled when the data buffer has been initialized and the format/channels/rate can be retrieved.
getter/setter pair
pResourceManager Pointer<Void>
ma_resource_manager
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited