flags$1 property
Resource manager data source flags that were used when initializing the data buffer.
Implementation
@ma_uint32()
external int flags$1;
Resource manager data source flags that were used when initializing the data buffer.
@ma_uint32()
external int flags$1;