UnnamedStruct$40 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct$40()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
pDataBufferNode Pointer<Void>
ma_resource_manager_data_buffer_node
getter/setter pair
pDecoder Pointer<Void>
ma_decoder
getter/setter pair
pDoneFence Pointer<ma_fence>
Passed through from LOAD_DATA_BUFFER_NODE and released when the data buffer completes decoding or an error occurs.
getter/setter pair
pDoneNotification Pointer<Void>
Signalled when the data buffer has been fully decoded.
getter/setter pair
pResourceManager Pointer<Void>
ma_resource_manager
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited