UnnamedStruct$41 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct$41()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
isLooping int
getter/setter pair
loopPointBegInPCMFrames int
getter/setter pair
loopPointEndInPCMFrames int
getter/setter pair
pDataBuffer Pointer<Void>
ma_resource_manager_data_buffer
getter/setter pair
pDoneFence Pointer<ma_fence>
Released when the data buffer has been fully decoded.
getter/setter pair
pDoneNotification Pointer<Void>
Signalled when the data buffer has been fully decoded.
getter/setter pair
pInitFence Pointer<ma_fence>
Released when the data buffer has been initialized and the format/channels/rate can be retrieved.
getter/setter pair
pInitNotification Pointer<Void>
Signalled when the data buffer has been initialized and the format/channels/rate can be retrieved.
getter/setter pair
rangeBegInPCMFrames int
getter/setter pair
rangeEndInPCMFrames int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited