UnnamedStruct$43 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedStruct$43()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
initialSeekPoint int
getter/setter pair
pDataStream Pointer<Void>
ma_resource_manager_data_stream
getter/setter pair
pFilePath Pointer<Char>
Allocated when the job is posted, freed by the job thread after loading.
getter/setter pair
pFilePathW Pointer<WChar>
^ As above ^. Only used if pFilePath is NULL.
getter/setter pair
pInitFence Pointer<ma_fence>
getter/setter pair
pInitNotification Pointer<Void>
Signalled after the first two pages have been decoded and frames can be read from the stream.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited