pInitNotification property

Pointer<Void> pInitNotification
getter/setter pair

Signalled after the first two pages have been decoded and frames can be read from the stream.

Implementation

external ffi.Pointer<ma_async_notification> pInitNotification;