fadeLengthInFrames property
<-- Defaults to (~(ma_uint64)0) which is used to indicate that no fade should be applied.
Implementation
external ma_atomic_uint64 fadeLengthInFrames;
<-- Defaults to (~(ma_uint64)0) which is used to indicate that no fade should be applied.
external ma_atomic_uint64 fadeLengthInFrames;