UnnamedStruct$9 class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- pa_channel_map_compatible ↔ ma_proc
-
getter/setter pair
- pa_channel_map_init_extend ↔ ma_proc
-
getter/setter pair
- pa_channel_map_valid ↔ ma_proc
-
getter/setter pair
- pa_context_connect ↔ ma_proc
-
getter/setter pair
- pa_context_disconnect ↔ ma_proc
-
getter/setter pair
- pa_context_get_sink_info_by_name ↔ ma_proc
-
getter/setter pair
- pa_context_get_sink_info_list ↔ ma_proc
-
getter/setter pair
- pa_context_get_source_info_by_name ↔ ma_proc
-
getter/setter pair
- pa_context_get_source_info_list ↔ ma_proc
-
getter/setter pair
- pa_context_get_state ↔ ma_proc
-
getter/setter pair
- pa_context_new ↔ ma_proc
-
getter/setter pair
- pa_context_set_state_callback ↔ ma_proc
-
getter/setter pair
- pa_context_unref ↔ ma_proc
-
getter/setter pair
- pa_mainloop_free ↔ ma_proc
-
getter/setter pair
- pa_mainloop_get_api ↔ ma_proc
-
getter/setter pair
- pa_mainloop_iterate ↔ ma_proc
-
getter/setter pair
- pa_mainloop_new ↔ ma_proc
-
getter/setter pair
- pa_mainloop_quit ↔ ma_proc
-
getter/setter pair
- pa_mainloop_wakeup ↔ ma_proc
-
getter/setter pair
- pa_operation_get_state ↔ ma_proc
-
getter/setter pair
- pa_operation_unref ↔ ma_proc
-
getter/setter pair
- pa_stream_begin_write ↔ ma_proc
-
getter/setter pair
- pa_stream_connect_playback ↔ ma_proc
-
getter/setter pair
- pa_stream_connect_record ↔ ma_proc
-
getter/setter pair
- pa_stream_cork ↔ ma_proc
-
getter/setter pair
- pa_stream_disconnect ↔ ma_proc
-
getter/setter pair
- pa_stream_drain ↔ ma_proc
-
getter/setter pair
- pa_stream_drop ↔ ma_proc
-
getter/setter pair
- pa_stream_flush ↔ ma_proc
-
getter/setter pair
- pa_stream_get_buffer_attr ↔ ma_proc
-
getter/setter pair
- pa_stream_get_channel_map ↔ ma_proc
-
getter/setter pair
- pa_stream_get_device_name ↔ ma_proc
-
getter/setter pair
- pa_stream_get_sample_spec ↔ ma_proc
-
getter/setter pair
- pa_stream_get_state ↔ ma_proc
-
getter/setter pair
- pa_stream_is_corked ↔ ma_proc
-
getter/setter pair
- pa_stream_is_suspended ↔ ma_proc
-
getter/setter pair
- pa_stream_new ↔ ma_proc
-
getter/setter pair
- pa_stream_peek ↔ ma_proc
-
getter/setter pair
- pa_stream_readable_size ↔ ma_proc
-
getter/setter pair
- pa_stream_set_buffer_attr ↔ ma_proc
-
getter/setter pair
- pa_stream_set_moved_callback ↔ ma_proc
-
getter/setter pair
- pa_stream_set_read_callback ↔ ma_proc
-
getter/setter pair
- pa_stream_set_suspended_callback ↔ ma_proc
-
getter/setter pair
- pa_stream_set_write_callback ↔ ma_proc
-
getter/setter pair
- pa_stream_trigger ↔ ma_proc
-
getter/setter pair
- pa_stream_unref ↔ ma_proc
-
getter/setter pair
- pa_stream_writable_size ↔ ma_proc
-
getter/setter pair
- pa_stream_write ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_accept ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_free ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_get_api ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_get_retval ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_in_thread ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_lock ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_new ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_set_name ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_signal ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_start ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_stop ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_unlock ↔ ma_proc
-
getter/setter pair
- pa_threaded_mainloop_wait ↔ ma_proc
-
getter/setter pair
-
pApplicationName
↔ Pointer<
Char> -
Set when the context is initialized. Used by devices for their local pa_context objects.
getter/setter pair
-
pMainLoop
↔ Pointer<
Void> -
pa_mainloop
getter/setter pair
-
pPulseContext
↔ Pointer<
Void> -
pa_context
getter/setter pair
-
pServerName
↔ Pointer<
Char> -
Set when the context is initialized. Used by devices for their local pa_context objects.
getter/setter pair
-
pulseSO
↔ Pointer<
Void> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited