UnnamedUnion$12 class final

Resource Manager

Inheritance
Implemented types
Available extensions

Constructors

UnnamedUnion$12()

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
freeDataBuffer UnnamedStruct$42
getter/setter pair
freeDataBufferNode UnnamedStruct$39
getter/setter pair
freeDataStream UnnamedStruct$44
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loadDataBuffer UnnamedStruct$41
getter/setter pair
loadDataBufferNode UnnamedStruct$38
getter/setter pair
loadDataStream UnnamedStruct$43
getter/setter pair
pageDataBufferNode UnnamedStruct$40
getter/setter pair
pageDataStream UnnamedStruct$45
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seekDataStream UnnamedStruct$46
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited