UnnamedUnion$2 class final

Inheritance
Implemented types
Available extensions

Constructors

UnnamedUnion$2()

Properties

address Pointer<T>

Available on T, provided by the UnionAddress extension

The memory address of the underlying data.
no setter
alsa UnnamedStruct$8
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jack UnnamedStruct$10
getter/setter pair
null_backend UnnamedStruct$11
getter/setter pair
pulse UnnamedStruct$9
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited