cJSON class final

The cJSON structure:

Inheritance
Implemented types
Available extensions

Constructors

cJSON()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
child Pointer<cJSON>
An array or object item will have a child pointer pointing to a chain of the items in the array/object.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
next Pointer<cJSON>
next/prev allow you to walk array/object chains. Alternatively, use GetArraySize/GetArrayItem/GetObjectItem
getter/setter pair
prev Pointer<cJSON>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string Pointer<Char>
The item's name string, if this item is the child of, or is in the list of subitems of an object.
getter/setter pair
type int
The type of the item, as above.
getter/setter pair
valuedouble double
The item's number, if type==cJSON_Number
getter/setter pair
valueint int
writing to valueint is DEPRECATED, use cJSON_SetNumberValue instead
getter/setter pair
valuestring Pointer<Char>
The item's string, if type==cJSON_String and type == cJSON_Raw
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited