child property

Pointer<cJSON> child
getter/setter pair

An array or object item will have a child pointer pointing to a chain of the items in the array/object.

Implementation

external ffi.Pointer<cJSON> child;