string property

Pointer<Char> string
getter/setter pair

The item's name string, if this item is the child of, or is in the list of subitems of an object.

Implementation

external ffi.Pointer<ffi.Char> string;