cJSON_GetArraySize function
Returns the number of items in an array (or object).
Implementation
@ffi.Native<ffi.Int Function(ffi.Pointer<cJSON>)>()
external int cJSON_GetArraySize(ffi.Pointer<cJSON> array);
Returns the number of items in an array (or object).
@ffi.Native<ffi.Int Function(ffi.Pointer<cJSON>)>()
external int cJSON_GetArraySize(ffi.Pointer<cJSON> array);