cJSON_Hooks class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
free_fn
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> ptr)> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
malloc_fn
↔ Pointer<
NativeFunction< Pointer< >Void> Function(Size sz)> -
malloc/free are CDECL on Windows regardless of the default calling convention of the compiler, so ensure the hooks allow passing those functions directly.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited