cJSON_Minify function
void
cJSON_Minify()
Minify a strings, remove blank characters(such as ' ', '\t', '\r', '\n') from strings. The input pointer json cannot point to a read-only address area, such as a string constant, but should point to a readable and writable address area.
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<ffi.Char>)>()
external void cJSON_Minify(ffi.Pointer<ffi.Char> json);