cJSON_Parse function

  1. @Native<Pointer<cJSON> Function(Pointer<Char> raw)>(ffi.Pointer<ffi.Char>)>()
Pointer<cJSON> cJSON_Parse(
  1. Pointer<Char> value
)

Memory Management: the caller is always responsible to free the results from all variants of cJSON_Parse (with cJSON_Delete) and cJSON_Print (with stdlib free, cJSON_Hooks.free_fn, or cJSON_free as appropriate). The exception is cJSON_PrintPreallocated, where the caller has full responsibility of the buffer. / / Supply a block of JSON, and this returns a cJSON object you can interrogate.

Implementation

@ffi.Native<ffi.Pointer<cJSON> Function(ffi.Pointer<ffi.Char>)>()
external ffi.Pointer<cJSON> cJSON_Parse(ffi.Pointer<ffi.Char> value);