crypto_argon2_config class final

Inheritance
Implemented types
Available extensions

Constructors

crypto_argon2_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
algorithm int
Argon2d, Argon2i, Argon2id
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nb_blocks int
memory hardness, >= 8 * nb_lanes
getter/setter pair
nb_lanes int
parallelism level (single threaded anyway)
getter/setter pair
nb_passes int
CPU hardness, >= 1 (>= 3 recommended for Argon2i)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited