hash property
Do not rely on the size or contents of this type, for they may change without notice.
Implementation
@ffi.Array.multi([8])
external ffi.Array<ffi.Uint64> hash;
Do not rely on the size or contents of this type, for they may change without notice.
@ffi.Array.multi([8])
external ffi.Array<ffi.Uint64> hash;