flags enum

Flag values for http_parser.flags field

Inheritance
Available extensions

Values

F_CHUNKED → const flags
const flags(1)
F_CONNECTION_KEEP_ALIVE → const flags
const flags(2)
F_CONNECTION_CLOSE → const flags
const flags(4)
F_CONNECTION_UPGRADE → const flags
const flags(8)
F_TRAILING → const flags
const flags(16)
F_UPGRADE → const flags
const flags(32)
F_SKIPBODY → const flags
const flags(64)
F_CONTENTLENGTH → const flags
const flags(128)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) flags

Constants

values → const List<flags>
A constant List of the values in this enum, in order of their declaration.