hexwave_shutdown function

  1. @Native<Void Function(Pointer<Float>)>(ffi.Pointer<ffi.Float>)>()
void hexwave_shutdown(
  1. Pointer<Float> user_buffer
)

width: size of BLEP, from 4..64, larger is slower & more memory but less aliasing oversample: 2+, number of subsample positions, larger uses more memory but less noise user_buffer: optional, if provided the library will perform no allocations. 16width(oversample+1) bytes, must stay allocated as long as library is used technically it only needs: 8*( width * (oversample + 1))

  • 8*((width * oversample) + 1) bytes

width can be larger than 64 if you define STB_HEXWAVE_MAX_BLEP_LENGTH to a larger value

Implementation

@ffi.Native<ffi.Void Function(ffi.Pointer<ffi.Float>)>()
external void hexwave_shutdown(ffi.Pointer<ffi.Float> user_buffer);