http_method enum
icecast
Values
- HTTP_DELETE → const http_method
-
const http_method(0) - HTTP_GET → const http_method
-
const http_method(1) - HTTP_HEAD → const http_method
-
const http_method(2) - HTTP_POST → const http_method
-
const http_method(3) - HTTP_PUT → const http_method
-
const http_method(4) - HTTP_CONNECT → const http_method
-
const http_method(5) - HTTP_OPTIONS → const http_method
-
const http_method(6) - HTTP_TRACE → const http_method
-
const http_method(7) - HTTP_COPY → const http_method
-
const http_method(8) - HTTP_LOCK → const http_method
-
const http_method(9) - HTTP_MKCOL → const http_method
-
const http_method(10) - HTTP_MOVE → const http_method
-
const http_method(11) - HTTP_PROPFIND → const http_method
-
const http_method(12) - HTTP_PROPPATCH → const http_method
-
const http_method(13) - HTTP_SEARCH → const http_method
-
const http_method(14) - HTTP_UNLOCK → const http_method
-
const http_method(15) - HTTP_BIND → const http_method
-
const http_method(16) - HTTP_REBIND → const http_method
-
const http_method(17) - HTTP_UNBIND → const http_method
-
const http_method(18) - HTTP_ACL → const http_method
-
const http_method(19) - HTTP_REPORT → const http_method
-
const http_method(20) - HTTP_MKACTIVITY → const http_method
-
const http_method(21) - HTTP_CHECKOUT → const http_method
-
const http_method(22) - HTTP_MERGE → const http_method
-
const http_method(23) - HTTP_MSEARCH → const http_method
-
const http_method(24) - HTTP_NOTIFY → const http_method
-
const http_method(25) - HTTP_SUBSCRIBE → const http_method
-
const http_method(26) - HTTP_UNSUBSCRIBE → const http_method
-
const http_method(27) - HTTP_PATCH → const http_method
-
const http_method(28) - HTTP_PURGE → const http_method
-
const http_method(29) - HTTP_MKCALENDAR → const http_method
-
const http_method(30) - HTTP_LINK → const http_method
-
const http_method(31) - HTTP_UNLINK → const http_method
-
const http_method(32) - HTTP_SOURCE → const http_method
-
const http_method(33)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → http_method
Constants
-
values
→ const List<
http_method> - A constant List of the values in this enum, in order of their declaration.