http_parser_settings class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- on_body ↔ http_data_cb
-
getter/setter pair
- on_chunk_complete ↔ http_cb
-
getter/setter pair
- on_chunk_header ↔ http_cb
-
When on_chunk_header is called, the current chunk length is stored
in parser->content_length.
getter/setter pair
- on_header_field ↔ http_data_cb
-
getter/setter pair
- on_header_value ↔ http_data_cb
-
getter/setter pair
- on_headers_complete ↔ http_cb
-
getter/setter pair
- on_message_begin ↔ http_cb
-
getter/setter pair
- on_message_complete ↔ http_cb
-
getter/setter pair
- on_status ↔ http_data_cb
-
getter/setter pair
- on_url ↔ http_data_cb
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited