on_chunk_header property
When on_chunk_header is called, the current chunk length is stored in parser->content_length.
Implementation
external http_cb on_chunk_header;
When on_chunk_header is called, the current chunk length is stored in parser->content_length.
external http_cb on_chunk_header;