http_status enum

Inheritance
Available extensions

Values

HTTP_STATUS_CONTINUE → const http_status
const http_status(100)
HTTP_STATUS_SWITCHING_PROTOCOLS → const http_status
const http_status(101)
HTTP_STATUS_PROCESSING → const http_status
const http_status(102)
HTTP_STATUS_OK → const http_status
const http_status(200)
HTTP_STATUS_CREATED → const http_status
const http_status(201)
HTTP_STATUS_ACCEPTED → const http_status
const http_status(202)
HTTP_STATUS_NON_AUTHORITATIVE_INFORMATION → const http_status
const http_status(203)
HTTP_STATUS_NO_CONTENT → const http_status
const http_status(204)
HTTP_STATUS_RESET_CONTENT → const http_status
const http_status(205)
HTTP_STATUS_PARTIAL_CONTENT → const http_status
const http_status(206)
HTTP_STATUS_MULTI_STATUS → const http_status
const http_status(207)
HTTP_STATUS_ALREADY_REPORTED → const http_status
const http_status(208)
HTTP_STATUS_IM_USED → const http_status
const http_status(226)
HTTP_STATUS_MULTIPLE_CHOICES → const http_status
const http_status(300)
HTTP_STATUS_MOVED_PERMANENTLY → const http_status
const http_status(301)
HTTP_STATUS_FOUND → const http_status
const http_status(302)
HTTP_STATUS_SEE_OTHER → const http_status
const http_status(303)
HTTP_STATUS_NOT_MODIFIED → const http_status
const http_status(304)
HTTP_STATUS_USE_PROXY → const http_status
const http_status(305)
HTTP_STATUS_TEMPORARY_REDIRECT → const http_status
const http_status(307)
HTTP_STATUS_PERMANENT_REDIRECT → const http_status
const http_status(308)
HTTP_STATUS_BAD_REQUEST → const http_status
const http_status(400)
HTTP_STATUS_UNAUTHORIZED → const http_status
const http_status(401)
HTTP_STATUS_PAYMENT_REQUIRED → const http_status
const http_status(402)
HTTP_STATUS_FORBIDDEN → const http_status
const http_status(403)
HTTP_STATUS_NOT_FOUND → const http_status
const http_status(404)
HTTP_STATUS_METHOD_NOT_ALLOWED → const http_status
const http_status(405)
HTTP_STATUS_NOT_ACCEPTABLE → const http_status
const http_status(406)
HTTP_STATUS_PROXY_AUTHENTICATION_REQUIRED → const http_status
const http_status(407)
HTTP_STATUS_REQUEST_TIMEOUT → const http_status
const http_status(408)
HTTP_STATUS_CONFLICT → const http_status
const http_status(409)
HTTP_STATUS_GONE → const http_status
const http_status(410)
HTTP_STATUS_LENGTH_REQUIRED → const http_status
const http_status(411)
HTTP_STATUS_PRECONDITION_FAILED → const http_status
const http_status(412)
HTTP_STATUS_PAYLOAD_TOO_LARGE → const http_status
const http_status(413)
HTTP_STATUS_URI_TOO_LONG → const http_status
const http_status(414)
HTTP_STATUS_UNSUPPORTED_MEDIA_TYPE → const http_status
const http_status(415)
HTTP_STATUS_RANGE_NOT_SATISFIABLE → const http_status
const http_status(416)
HTTP_STATUS_EXPECTATION_FAILED → const http_status
const http_status(417)
HTTP_STATUS_MISDIRECTED_REQUEST → const http_status
const http_status(421)
HTTP_STATUS_UNPROCESSABLE_ENTITY → const http_status
const http_status(422)
HTTP_STATUS_LOCKED → const http_status
const http_status(423)
HTTP_STATUS_FAILED_DEPENDENCY → const http_status
const http_status(424)
HTTP_STATUS_UPGRADE_REQUIRED → const http_status
const http_status(426)
HTTP_STATUS_PRECONDITION_REQUIRED → const http_status
const http_status(428)
HTTP_STATUS_TOO_MANY_REQUESTS → const http_status
const http_status(429)
HTTP_STATUS_REQUEST_HEADER_FIELDS_TOO_LARGE → const http_status
const http_status(431)
const http_status(451)
HTTP_STATUS_INTERNAL_SERVER_ERROR → const http_status
const http_status(500)
HTTP_STATUS_NOT_IMPLEMENTED → const http_status
const http_status(501)
HTTP_STATUS_BAD_GATEWAY → const http_status
const http_status(502)
HTTP_STATUS_SERVICE_UNAVAILABLE → const http_status
const http_status(503)
HTTP_STATUS_GATEWAY_TIMEOUT → const http_status
const http_status(504)
HTTP_STATUS_HTTP_VERSION_NOT_SUPPORTED → const http_status
const http_status(505)
HTTP_STATUS_VARIANT_ALSO_NEGOTIATES → const http_status
const http_status(506)
HTTP_STATUS_INSUFFICIENT_STORAGE → const http_status
const http_status(507)
HTTP_STATUS_LOOP_DETECTED → const http_status
const http_status(508)
HTTP_STATUS_NOT_EXTENDED → const http_status
const http_status(510)
HTTP_STATUS_NETWORK_AUTHENTICATION_REQUIRED → const http_status
const http_status(511)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) http_status

Constants

values → const List<http_status>
A constant List of the values in this enum, in order of their declaration.