ma_attenuation_model enum

Inheritance
Available extensions

Values

ma_attenuation_model_none → const ma_attenuation_model

No distance attenuation and no spatialization.

const ma_attenuation_model(0)
ma_attenuation_model_inverse → const ma_attenuation_model

Equivalent to OpenAL's AL_INVERSE_DISTANCE_CLAMPED.

const ma_attenuation_model(1)
ma_attenuation_model_linear → const ma_attenuation_model

Linear attenuation. Equivalent to OpenAL's AL_LINEAR_DISTANCE_CLAMPED.

const ma_attenuation_model(2)
ma_attenuation_model_exponential → const ma_attenuation_model

Exponential attenuation. Equivalent to OpenAL's AL_EXPONENT_DISTANCE_CLAMPED.

const ma_attenuation_model(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ma_attenuation_model

Constants

values → const List<ma_attenuation_model>
A constant List of the values in this enum, in order of their declaration.