ma_audio_buffer class final

Inheritance
Implemented types
Available extensions

Constructors

ma_audio_buffer()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allocationCallbacks ma_allocation_callbacks
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ownsData int
Used to control whether or not miniaudio owns the data buffer. If set to true, pData will be freed in ma_audio_buffer_uninit().
getter/setter pair
ref ma_audio_buffer_ref
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited