ownsData property
Used to control whether or not miniaudio owns the data buffer. If set to true, pData will be freed in ma_audio_buffer_uninit().
Implementation
@ma_bool32()
external int ownsData;
Used to control whether or not miniaudio owns the data buffer. If set to true, pData will be freed in ma_audio_buffer_uninit().
@ma_bool32()
external int ownsData;