ma_channel_map_contains_channel_position function

  1. @Native<ma_bool32 Function(ma_uint32, Pointer<ma_uint8>, ma_channel)>(ma_uint32, ffi.Pointer<ma_channel>, ma_channel)>()
int ma_channel_map_contains_channel_position(
  1. int channels,
  2. Pointer<ma_uint8> pChannelMap,
  3. int channelPosition
)

Helper for determining whether or not a channel is present in the given channel map.

The channel map buffer must have a capacity of at least channels.

Implementation

@ffi.Native<
  ma_bool32 Function(ma_uint32, ffi.Pointer<ma_channel>, ma_channel)
>()
external int ma_channel_map_contains_channel_position(
  int channels,
  ffi.Pointer<ma_channel> pChannelMap,
  int channelPosition,
);