ma_channel_map_find_channel_position function
Find a channel position in the given channel map. Returns MA_TRUE if the channel is found; MA_FALSE otherwise. The
index of the channel is output to pChannelIndex.
The channel map buffer must have a capacity of at least channels.
Implementation
@ffi.Native<
ma_bool32 Function(
ma_uint32,
ffi.Pointer<ma_channel>,
ma_channel,
ffi.Pointer<ma_uint32>,
)
>()
external int ma_channel_map_find_channel_position(
int channels,
ffi.Pointer<ma_channel> pChannelMap,
int channelPosition,
ffi.Pointer<ma_uint32> pChannelIndex,
);