ma_channel_map_init_blank function

  1. @Native<Void Function(Pointer<ma_uint8>, ma_uint32)>(ffi.Pointer<ma_channel>, ma_uint32)>()
void ma_channel_map_init_blank(
  1. Pointer<ma_uint8> pChannelMap,
  2. int channels
)

Initializes a blank channel map.

When a blank channel map is specified anywhere it indicates that the native channel map should be used.

Implementation

@ffi.Native<ffi.Void Function(ffi.Pointer<ma_channel>, ma_uint32)>()
external void ma_channel_map_init_blank(
  ffi.Pointer<ma_channel> pChannelMap,
  int channels,
);