ma_channel_map_is_valid function

  1. @Native<ma_bool32 Function(Pointer<ma_uint8>, ma_uint32)>(ffi.Pointer<ma_channel>, ma_uint32)>()
int ma_channel_map_is_valid(
  1. Pointer<ma_uint8> pChannelMap,
  2. int channels
)

Determines whether or not a channel map is valid.

A blank channel map is valid (all channels set to MA_CHANNEL_NONE). The way a blank channel map is handled is context specific, but is usually treated as a passthrough.

Invalid channel maps:

  • A channel map with no channels
  • A channel map with more than one channel and a mono channel

The channel map buffer must have a capacity of at least channels.

Implementation

@ffi.Native<ma_bool32 Function(ffi.Pointer<ma_channel>, ma_uint32)>()
external int ma_channel_map_is_valid(
  ffi.Pointer<ma_channel> pChannelMap,
  int channels,
);