ma_channel_map_to_string function

  1. @Native<Size Function(Pointer<ma_uint8>, ma_uint32, Pointer<Char>, Size)>(ffi.Pointer<ma_channel>, ma_uint32, ffi.Pointer<ffi.Char>, ffi.Size)>()
int ma_channel_map_to_string(
  1. Pointer<ma_uint8> pChannelMap,
  2. int channels,
  3. Pointer<Char> pBufferOut,
  4. int bufferCap,
)

Generates a string representing the given channel map.

This is for printing and debugging purposes, not serialization/deserialization.

Returns the length of the string, not including the null terminator.

Implementation

@ffi.Native<
  ffi.Size Function(
    ffi.Pointer<ma_channel>,
    ma_uint32,
    ffi.Pointer<ffi.Char>,
    ffi.Size,
  )
>()
external int ma_channel_map_to_string(
  ffi.Pointer<ma_channel> pChannelMap,
  int channels,
  ffi.Pointer<ffi.Char> pBufferOut,
  int bufferCap,
);