ma_context_config_init function
Initializes a ma_context_config object.
Return Value
A ma_context_config initialized to defaults.
Remarks
You must always use this to initialize the default state of the ma_context_config object. Not using this will result in your program breaking when miniaudio
is updated and new members are added to ma_context_config. It also sets logical defaults.
You can override members of the returned object by changing it's members directly.
See Also
ma_context_init()
Implementation
@ffi.Native<ma_context_config Function()>()
external ma_context_config ma_context_config_init();