executionPathAsInt property
The execution path the data converter will follow when processing.
Implementation
@ffi.UnsignedInt()
external int executionPathAsInt;
The execution path the data converter will follow when processing.
@ffi.UnsignedInt()
external int executionPathAsInt;