ma_data_converter_config class final

Data Conversion

Inheritance
Implemented types
Available extensions

Constructors

ma_data_converter_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allowDynamicSampleRate int
getter/setter pair
calculateLFEFromSpatialChannels int
When an output LFE channel is present, but no input LFE, set to true to set the output LFE to the average of all spatial channels (LR, FR, etc.). Ignored when an input LFE is present.
getter/setter pair
channelMixMode ma_channel_mix_mode
no setter
channelMixModeAsInt int
getter/setter pair
channelsIn int
getter/setter pair
channelsOut int
getter/setter pair
ditherMode ma_dither_mode
no setter
ditherModeAsInt int
getter/setter pair
formatIn ma_format
no setter
formatInAsInt int
getter/setter pair
formatOut ma_format
no setter
formatOutAsInt int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pChannelMapIn Pointer<ma_uint8>
getter/setter pair
pChannelMapOut Pointer<ma_uint8>
getter/setter pair
ppChannelWeights Pointer<Pointer<Float>>
out. Only used when mixingMode is set to ma_channel_mix_mode_custom_weights.
getter/setter pair
resampling ma_resampler_config
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRateIn int
getter/setter pair
sampleRateOut int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited