ma_data_source_vtable class final

Inheritance
Implemented types
Available extensions

Constructors

ma_data_source_vtable()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags$1 int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onGetCursor Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, Pointer<ma_uint64> pCursor)>>
getter/setter pair
onGetDataFormat Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, Pointer<ma_uint32> pFormat, Pointer<ma_uint32> pChannels, Pointer<ma_uint32> pSampleRate, Pointer<ma_uint8> pChannelMap, Size channelMapCap)>>
getter/setter pair
onGetLength Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, Pointer<ma_uint64> pCursor)>>
getter/setter pair
onRead Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, Pointer<Void> pFramesOut, ma_uint64 frameCount, Pointer<ma_uint64> pFramesRead)>>
getter/setter pair
onSeek Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, ma_uint64 frameIndex)>>
getter/setter pair
onSetLooping Pointer<NativeFunction<Int Function(Pointer<Void> pDataSource, ma_bool32 isLooping)>>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited