ma_decoder class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - allocationCallbacks ↔ ma_allocation_callbacks
-
getter/setter pair
- converter ↔ ma_data_converter
-
Data conversion is achieved by running frames through this.
getter/setter pair
- data ↔ UnnamedUnion$9
-
getter/setter pair
- ds ↔ ma_data_source_base
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputCacheCap ↔ int
-
The capacity of the input cache.
getter/setter pair
- inputCacheConsumed ↔ int
-
The number of frames that have been consumed in the cache. Used for determining the next valid frame.
getter/setter pair
- inputCacheRemaining ↔ int
-
The number of valid frames remaining in the cache.
getter/setter pair
- onRead ↔ ma_decoder_read_proc
-
getter/setter pair
- onSeek ↔ ma_decoder_seek_proc
-
getter/setter pair
- onTell ↔ ma_decoder_tell_proc
-
getter/setter pair
- outputChannels ↔ int
-
getter/setter pair
- outputFormat → ma_format
-
no setter
- outputFormatAsInt ↔ int
-
getter/setter pair
- outputSampleRate ↔ int
-
getter/setter pair
-
pBackend
↔ Pointer<
Void> -
The decoding backend we'll be pulling data from.
getter/setter pair
-
pBackendUserData
↔ Pointer<
Void> -
getter/setter pair
-
pBackendVTable
↔ Pointer<
ma_decoding_backend_vtable> -
The vtable for the decoding backend. This needs to be stored so we can access the onUninit() callback.
getter/setter pair
-
pInputCache
↔ Pointer<
Void> -
In input format. Can be null if it's not needed.
getter/setter pair
-
pUserData
↔ Pointer<
Void> -
getter/setter pair
- readPointerInPCMFrames ↔ int
-
In output sample rate. Used for keeping track of how many frames are available for decoding.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited