inputCacheConsumed property
The number of frames that have been consumed in the cache. Used for determining the next valid frame.
Implementation
@ma_uint64()
external int inputCacheConsumed;
The number of frames that have been consumed in the cache. Used for determining the next valid frame.
@ma_uint64()
external int inputCacheConsumed;