pBackendVTable property
The vtable for the decoding backend. This needs to be stored so we can access the onUninit() callback.
Implementation
external ffi.Pointer<ma_decoding_backend_vtable> pBackendVTable;
The vtable for the decoding backend. This needs to be stored so we can access the onUninit() callback.
external ffi.Pointer<ma_decoding_backend_vtable> pBackendVTable;