ma_decoder_config class final

Inheritance
Implemented types
Available extensions

Constructors

ma_decoder_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allocationCallbacks ma_allocation_callbacks
getter/setter pair
channelMixMode ma_channel_mix_mode
no setter
channelMixModeAsInt int
getter/setter pair
channels int
Set to 0 to use the stream's internal channels.
getter/setter pair
customBackendCount int
getter/setter pair
ditherMode ma_dither_mode
no setter
ditherModeAsInt int
getter/setter pair
encodingFormat ma_encoding_format
no setter
encodingFormatAsInt int
getter/setter pair
format ma_format
no setter
formatAsInt int
Set to 0 or ma_format_unknown to use the stream's internal format.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pChannelMap Pointer<ma_uint8>
getter/setter pair
pCustomBackendUserData Pointer<Void>
getter/setter pair
ppCustomBackendVTables Pointer<Pointer<ma_decoding_backend_vtable>>
getter/setter pair
resampling ma_resampler_config
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
Set to 0 to use the stream's internal sample rate.
getter/setter pair
seekPointCount int
When set to > 0, specifies the number of seek points to use for the generation of a seek table. Not all decoding backends support this.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited