seekPointCount property
When set to > 0, specifies the number of seek points to use for the generation of a seek table. Not all decoding backends support this.
Implementation
@ma_uint32()
external int seekPointCount;
When set to > 0, specifies the number of seek points to use for the generation of a seek table. Not all decoding backends support this.
@ma_uint32()
external int seekPointCount;