ma_delay class final

Inheritance
Implemented types
Available extensions

Constructors

ma_delay()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bufferSizeInFrames int
getter/setter pair
config ma_delay_config
getter/setter pair
cursor int
Feedback is written to this cursor. Always equal or in front of the read cursor.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pBuffer Pointer<Float>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited