cursor property
Feedback is written to this cursor. Always equal or in front of the read cursor.
Implementation
@ma_uint32()
external int cursor;
Feedback is written to this cursor. Always equal or in front of the read cursor.
@ma_uint32()
external int cursor;