ma_delay_config class final
Delay
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channels ↔ int
-
getter/setter pair
- decay ↔ double
-
0..1. Default = 0 (no feedback). Feedback decay. Use this for echo.
getter/setter pair
- delayInFrames ↔ int
-
getter/setter pair
- delayStart ↔ int
-
Set to true to delay the start of the output; false otherwise.
getter/setter pair
- dry ↔ double
-
0..1. Default = 1.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
getter/setter pair
- wet ↔ double
-
0..1. Default = 1.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited