ma_device class final

Inheritance
Implemented types
Available extensions

Constructors

ma_device()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
capture UnnamedStruct$21
getter/setter pair
duplexRB ma_duplex_rb
Intermediary buffer for duplex device on asynchronous backends.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isOwnerOfContext int
When set to true, uninitializing the device will also uninitialize the context. Set to true when NULL is passed into ma_device_init().
getter/setter pair
masterVolumeFactor ma_atomic_float
Linear 0..1. Can be read and written simultaneously by different threads. Must be used atomically.
getter/setter pair
noClip int
getter/setter pair
noDisableDenormals int
getter/setter pair
noFixedSizedCallback int
getter/setter pair
noPreSilencedOutputBuffer int
getter/setter pair
onData ma_device_data_proc
Set once at initialization time and should not be changed after.
getter/setter pair
onNotification ma_device_notification_proc
Set once at initialization time and should not be changed after.
getter/setter pair
onStop ma_stop_proc
DEPRECATED. Use the notification callback instead. Set once at initialization time and should not be changed after.
getter/setter pair
pContext Pointer<ma_context>
getter/setter pair
playback UnnamedStruct$20
getter/setter pair
pUserData Pointer<Void>
Application defined data.
getter/setter pair
resampling UnnamedStruct$17
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
startEvent ma_event
getter/setter pair
startStopLock ma_mutex
getter/setter pair
state ma_atomic_device_state
The state of the device is variable and can change at any time on any thread. Must be used atomically.
getter/setter pair
stopEvent ma_event
getter/setter pair
thread int
getter/setter pair
type ma_device_type
no setter
typeAsInt int
getter/setter pair
unnamed UnnamedUnion$8
getter/setter pair
wakeupEvent ma_event
getter/setter pair
workResult ma_result
no setter
workResultAsInt int
This is set by the worker thread after it's finished doing a job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited