ma_device_config class final

Inheritance
Implemented types
Available extensions

Constructors

ma_device_config()

Properties

aaudio UnnamedStruct$33
getter/setter pair
address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
alsa UnnamedStruct$29
getter/setter pair
capture UnnamedStruct$27
getter/setter pair
coreaudio UnnamedStruct$31
getter/setter pair
dataCallback ma_device_data_proc
getter/setter pair
deviceType ma_device_type
no setter
deviceTypeAsInt int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
noClip int
When set to true, the contents of the output buffer passed into the data callback will not be clipped after returning. Only applies when the playback sample format is f32.
getter/setter pair
noDisableDenormals int
Do not disable denormals when firing the data callback.
getter/setter pair
noFixedSizedCallback int
Disables strict fixed-sized data callbacks. Setting this to true will result in the period size being treated only as a hint to the backend. This is an optimization for those who don't need fixed sized callbacks.
getter/setter pair
noPreSilencedOutputBuffer int
When set to true, the contents of the output buffer passed into the data callback will be left undefined rather than initialized to silence.
getter/setter pair
notificationCallback ma_device_notification_proc
getter/setter pair
opensl UnnamedStruct$32
getter/setter pair
performanceProfile ma_performance_profile
no setter
performanceProfileAsInt int
getter/setter pair
periods int
getter/setter pair
periodSizeInFrames int
getter/setter pair
periodSizeInMilliseconds int
getter/setter pair
playback UnnamedStruct$26
getter/setter pair
pulse UnnamedStruct$30
getter/setter pair
pUserData Pointer<Void>
getter/setter pair
resampling ma_resampler_config
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
stopCallback ma_stop_proc
getter/setter pair
wasapi UnnamedStruct$28
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited