ma_device_is_started function

  1. @Native<ma_bool32 Function(Pointer<ma_device>)>(ffi.Pointer<ma_device>)>()
int ma_device_is_started(
  1. Pointer<ma_device> pDevice
)

Determines whether or not the device is started.

Parameters

pDevice (in) A pointer to the device whose start state is being retrieved.

Return Value

True if the device is started, false otherwise.

Thread Safety

Safe. If another thread calls ma_device_start() or ma_device_stop() at this same time as this function is called, there's a very small chance the return value will be out of sync.

Callback Safety

Safe. This is implemented as a simple accessor.

See Also

ma_device_start() ma_device_stop()

Implementation

@ffi.Native<ma_bool32 Function(ffi.Pointer<ma_device>)>()
external int ma_device_is_started(ffi.Pointer<ma_device> pDevice);