ma_device_uninit function
void
ma_device_uninit()
Uninitializes a device.
This will explicitly stop the device. You do not need to call ma_device_stop() beforehand, but it's harmless if you do.
Parameters
pDevice (in) A pointer to the device to stop.
Return Value
Nothing
Thread Safety
Unsafe. As soon as this API is called the device should be considered undefined.
Callback Safety
Unsafe. It is not safe to call this inside any callback. Doing this will result in a deadlock.
See Also
ma_device_init() ma_device_stop()
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<ma_device>)>()
external void ma_device_uninit(ffi.Pointer<ma_device> pDevice);