ma_engine class final

Inheritance
Implemented types
Available extensions

Constructors

ma_engine()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allocationCallbacks ma_allocation_callbacks
getter/setter pair
defaultVolumeSmoothTimeInPCMFrames int
getter/setter pair
gainSmoothTimeInFrames int
The number of frames to interpolate the gain of spatialized sounds across.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inlinedSoundCount int
The total number of allocated inlined sound objects. Used for debugging.
getter/setter pair
inlinedSoundLock int
For synchronizing access to the inlined sound list.
getter/setter pair
listenerCount int
getter/setter pair
listeners Array<ma_spatializer_listener>
getter/setter pair
monoExpansionMode ma_mono_expansion_mode
no setter
monoExpansionModeAsInt int
getter/setter pair
nodeGraph ma_node_graph
An engine is a node graph. It should be able to be plugged into any ma_node_graph API (with a cast) which means this must be the first member of this struct.
getter/setter pair
onProcess ma_engine_process_proc
getter/setter pair
ownsDevice int
getter/setter pair
ownsResourceManager int
getter/setter pair
pDevice Pointer<ma_device>
Optionally set via the config, otherwise allocated by the engine in ma_engine_init().
getter/setter pair
pInlinedSoundHead Pointer<ma_sound_inlined>
The first inlined sound. Inlined sounds are tracked in a linked list.
getter/setter pair
pitchResamplingConfig ma_resampler_config
getter/setter pair
pLog Pointer<ma_log>
getter/setter pair
pProcessUserData Pointer<Void>
getter/setter pair
pResourceManager Pointer<ma_resource_manager>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited