gainSmoothTimeInFrames property
The number of frames to interpolate the gain of spatialized sounds across.
Implementation
@ma_uint32()
external int gainSmoothTimeInFrames;
The number of frames to interpolate the gain of spatialized sounds across.
@ma_uint32()
external int gainSmoothTimeInFrames;