nodeGraph property

ma_node_graph nodeGraph
getter/setter pair

An engine is a node graph. It should be able to be plugged into any ma_node_graph API (with a cast) which means this must be the first member of this struct.

Implementation

external ma_node_graph nodeGraph;