channels property

  1. @UnsignedInt()
int channels
getter/setter pair

The number of channels to use when mixing and spatializing. When set to 0, will use the native channel count of the device.

Implementation

@ma_uint32()
external int channels;