defaultVolumeSmoothTimeInPCMFrames property
Defaults to 0. Controls the default amount of smoothing to apply to volume changes to sounds. High values means more smoothing at the expense of high latency (will take longer to reach the new volume).
Implementation
@ma_uint32()
external int defaultVolumeSmoothTimeInPCMFrames;