gainSmoothTimeInFrames property
The number of frames to interpolate the gain of spatialized sounds across. If set to 0, will use gainSmoothTimeInMilliseconds.
Implementation
@ma_uint32()
external int gainSmoothTimeInFrames;
The number of frames to interpolate the gain of spatialized sounds across. If set to 0, will use gainSmoothTimeInMilliseconds.
@ma_uint32()
external int gainSmoothTimeInFrames;