monoExpansionModeAsInt property
Controls how the mono channel should be expanded to other channels when spatialization is disabled on a sound.
Implementation
@ffi.UnsignedInt()
external int monoExpansionModeAsInt;
Controls how the mono channel should be expanded to other channels when spatialization is disabled on a sound.
@ffi.UnsignedInt()
external int monoExpansionModeAsInt;