onProcess property

ma_engine_process_proc onProcess
getter/setter pair

Fired at the end of each call to ma_engine_read_pcm_frames(). For engine's that manage their own internal device (the default configuration), this will be fired from the audio thread, and you do not need to call ma_engine_read_pcm_frames() manually in order to trigger this.

Implementation

external ma_engine_process_proc onProcess;