pPlaybackDeviceID property
The ID of the playback device to use with the default listener.
Implementation
external ffi.Pointer<ma_device_id> pPlaybackDeviceID;
The ID of the playback device to use with the default listener.
external ffi.Pointer<ma_device_id> pPlaybackDeviceID;