periodSizeInFrames property

  1. @UnsignedInt()
int periodSizeInFrames
getter/setter pair

If set to something other than 0, updates will always be exactly this size. The underlying device may be a different size, but from the perspective of the mixer that won't matter.

Implementation

@ma_uint32()
external int periodSizeInFrames;