pitchResampling property

ma_resampler_config pitchResampling
getter/setter pair

The resampling config for the pitch and Doppler effects. You will typically want this to be a fast resampler. For high quality stuff, it's recommended that you pre-resample.

Implementation

external ma_resampler_config pitchResampling;