preMixStackSizeInBytes property
A stack is used for internal processing in the node graph. This allows you to configure the size of this stack. Smaller values will reduce the maximum depth of your node graph. You should rarely need to modify this.
Implementation
@ma_uint32()
external int preMixStackSizeInBytes;