resourceManagerResampling property
The resampling config to use with the resource manager.
Implementation
external ma_resampler_config resourceManagerResampling;
The resampling config to use with the resource manager.
external ma_resampler_config resourceManagerResampling;