sampleRate property
The sample rate. When set to 0 will use the native sample rate of the device.
Implementation
@ma_uint32()
external int sampleRate;
The sample rate. When set to 0 will use the native sample rate of the device.
@ma_uint32()
external int sampleRate;