isSpatializationDisabled property
Set to false by default. When set to false, will not have spatialisation applied.
Implementation
@ma_bool32()
external int isSpatializationDisabled;
Set to false by default. When set to false, will not have spatialisation applied.
@ma_bool32()
external int isSpatializationDisabled;