oldDopplerPitch property

  1. @Float()
double oldDopplerPitch
getter/setter pair

For determining whether or not the resampler needs to be updated to take a new doppler pitch into account.

Implementation

@ffi.Float()
external double oldDopplerPitch;