oldPitch property

  1. @Float()
double oldPitch
getter/setter pair

For determining whether or not the resampler needs to be updated to reflect the new pitch. The resampler will be updated on the mixing thread.

Implementation

@ffi.Float()
external double oldPitch;