sampleRate property
The sample rate of the input data. For sounds backed by a data source, this will be the data source's sample rate. Otherwise it'll be the engine's sample rate.
Implementation
@ma_uint32()
external int sampleRate;
The sample rate of the input data. For sounds backed by a data source, this will be the data source's sample rate. Otherwise it'll be the engine's sample rate.
@ma_uint32()
external int sampleRate;