ma_hpf class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- ma_hpf()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channels ↔ int
-
getter/setter pair
- format → ma_format
-
no setter
- formatAsInt ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hpf1Count ↔ int
-
getter/setter pair
- hpf2Count ↔ int
-
getter/setter pair
-
pHPF1
↔ Pointer<
ma_hpf1> -
getter/setter pair
-
pHPF2
↔ Pointer<
ma_hpf2> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited