ma_job class final

Inheritance
Implemented types
Available extensions

Constructors

ma_job()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data UnnamedUnion$11
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
next int
refcount + slot for the next item. Does not include the job code.
getter/setter pair
order int
Execution order. Used to create a data dependency and ensure a job is executed in order. Usage is contextual depending on the job type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toc UnnamedUnion$10
8 bytes. We encode the job code into the slot allocation data to save space.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited