order property
Execution order. Used to create a data dependency and ensure a job is executed in order. Usage is contextual depending on the job type.
Implementation
@ma_uint32()
external int order;
Execution order. Used to create a data dependency and ensure a job is executed in order. Usage is contextual depending on the job type.
@ma_uint32()
external int order;