capacity property
The maximum number of jobs that can fit in the queue at a time. Set by the config.
Implementation
@ma_uint32()
external int capacity;
The maximum number of jobs that can fit in the queue at a time. Set by the config.
@ma_uint32()
external int capacity;