ma_loshelf_node_config class final

Low Shelf Filter Node

Inheritance
Implemented types
Available extensions

Constructors

ma_loshelf_node_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
loshelf ma_loshelf_config
getter/setter pair
nodeConfig ma_node_config
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited