ma_node_base class final

Inheritance
Implemented types
Available extensions

Constructors

ma_node_base()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
cachedDataCapInFramesPerBus int
The capacity of the input data cache in frames, per bus.
getter/setter pair
cachedFrameCountIn int
getter/setter pair
cachedFrameCountOut int
These variables are read and written only from the audio thread.
getter/setter pair
consumedFrameCountIn int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputBusCount int
getter/setter pair
localTime int
The node's local clock. This is just a running sum of the number of output frames that have been processed. Can be modified by any thread with ma_node_set_time().
getter/setter pair
outputBusCount int
getter/setter pair
pCachedData Pointer<Float>
Allocated on the heap. Fixed size. Needs to be stored on the heap because reading from output buses is done in separate function calls.
getter/setter pair
pInputBuses Pointer<ma_node_input_bus>
getter/setter pair
pNodeGraph Pointer<ma_node_graph>
The graph this node belongs to.
getter/setter pair
pOutputBuses Pointer<ma_node_output_bus>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ma_node_state
no setter
stateAsInt int
When set to stopped, nothing will be read, regardless of the times in stateTimes.
getter/setter pair
stateTimes Array<ma_uint64>
Indexed by ma_node_state. Specifies the time based on the global clock that a node should be considered to be in the relevant state.
getter/setter pair
vtable Pointer<ma_node_vtable>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited