cachedDataCapInFramesPerBus property
The capacity of the input data cache in frames, per bus.
Implementation
@ma_uint16()
external int cachedDataCapInFramesPerBus;
The capacity of the input data cache in frames, per bus.
@ma_uint16()
external int cachedDataCapInFramesPerBus;