cachedFrameCountOut property
These variables are read and written only from the audio thread.
Implementation
@ma_uint16()
external int cachedFrameCountOut;
These variables are read and written only from the audio thread.
@ma_uint16()
external int cachedFrameCountOut;