localTime property
The node's local clock. This is just a running sum of the number of output frames that have been processed. Can be modified by any thread with ma_node_set_time().
Implementation
@ma_uint64()
external int localTime;
The node's local clock. This is just a running sum of the number of output frames that have been processed. Can be modified by any thread with ma_node_set_time().
@ma_uint64()
external int localTime;