pCachedData property

Pointer<Float> pCachedData
getter/setter pair

Allocated on the heap. Fixed size. Needs to be stored on the heap because reading from output buses is done in separate function calls.

Implementation

external ffi.Pointer<ffi.Float> pCachedData;