stateAsInt property
When set to stopped, nothing will be read, regardless of the times in stateTimes.
Implementation
@ffi.UnsignedInt()
external int stateAsInt;
When set to stopped, nothing will be read, regardless of the times in stateTimes.
@ffi.UnsignedInt()
external int stateAsInt;