inputBusCount property
Only used if the vtable specifies an input bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise must be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
Implementation
@ma_uint32()
external int inputBusCount;
Only used if the vtable specifies an input bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise must be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
@ma_uint32()
external int inputBusCount;