outputBusCount property
Only used if the vtable specifies an output bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
Implementation
@ma_uint32()
external int outputBusCount;
Only used if the vtable specifies an output bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
@ma_uint32()
external int outputBusCount;