pInputChannels property

Pointer<ma_uint32> pInputChannels
getter/setter pair

The number of elements are determined by the input bus count as determined by the vtable, or inputBusCount if the vtable specifies MA_NODE_BUS_COUNT_UNKNOWN.

Implementation

external ffi.Pointer<ma_uint32> pInputChannels;