ma_node_flags enum

Node flags.

Inheritance
Available extensions

Values

MA_NODE_FLAG_PASSTHROUGH → const ma_node_flags
const ma_node_flags(1)
MA_NODE_FLAG_CONTINUOUS_PROCESSING → const ma_node_flags
const ma_node_flags(2)
MA_NODE_FLAG_ALLOW_NULL_INPUT → const ma_node_flags
const ma_node_flags(4)
MA_NODE_FLAG_DIFFERENT_PROCESSING_RATES → const ma_node_flags
const ma_node_flags(8)
MA_NODE_FLAG_SILENT_OUTPUT → const ma_node_flags
const ma_node_flags(16)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ma_node_flags

Constants

values → const List<ma_node_flags>
A constant List of the values in this enum, in order of their declaration.