base property

ma_node_base base
getter/setter pair

The node graph itself is a node so it can be connected as an input to different node graph. This has zero inputs and calls ma_node_graph_read_pcm_frames() to generate it's output.

Implementation

external ma_node_base base;