pProcessingCache property

Pointer<Float> pProcessingCache
getter/setter pair

This will be allocated when processingSizeInFrames is non-zero. This is needed because ma_node_graph_read_pcm_frames() can be called with a variable number of frames, and we may need to do some buffering in situations where the caller requests a frame count that's not a multiple of processingSizeInFrames.

Implementation

external ffi.Pointer<ffi.Float> pProcessingCache;