ma_node_graph_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channels ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- preMixStackSizeInBytes ↔ int
-
Defaults to 512KB per channel. Reducing this will save memory, but the depth of your node graph will be more restricted.
getter/setter pair
- processingSizeInFrames ↔ int
-
This is the preferred processing size for node processing callbacks unless overridden by a node itself. Can be 0 in which case it will be based on the frame count passed into ma_node_graph_read_pcm_frames(), but will not be well defined.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited