ma_node_input_bus class final

Inheritance
Implemented types
Available extensions

Constructors

ma_node_input_bus()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
channels int
The number of channels in the audio stream for this bus.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
Dummy head node for simplifying some lock-free thread-safety stuff.
getter/setter pair
lock int
Unfortunate lock, but significantly simplifies the implementation. Required for thread-safe attaching and detaching.
getter/setter pair
nextCounter int
This is used to determine whether or not the input bus is finding the next node in the list. Used for thread safety when detaching output buses.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited