flags$1 property
Some state flags for tracking the read state of the output buffer. A combination of MA_NODE_OUTPUT_BUS_FLAG_*.
Implementation
@ma_uint32()
external int flags$1;
Some state flags for tracking the read state of the output buffer. A combination of MA_NODE_OUTPUT_BUS_FLAG_*.
@ma_uint32()
external int flags$1;