isAttached property
This is used to prevent iteration of nodes that are in the middle of being detached. Used for thread safety.
Implementation
@ma_bool32()
external int isAttached;
This is used to prevent iteration of nodes that are in the middle of being detached. Used for thread safety.
@ma_bool32()
external int isAttached;