ma_node_vtable class final

Inheritance
Implemented types
Available extensions

Constructors

ma_node_vtable()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
flags$1 int
Flags describing characteristics of the node. This is currently just a placeholder for some ideas for later on.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputBusCount int
The number of input buses. This is how many sub-buffers will be contained in the ppFramesIn parameters of the callbacks above.
getter/setter pair
onGetRequiredInputFrameCount Pointer<NativeFunction<Int Function(Pointer<Void> pNode, ma_uint32 outputFrameCount, Pointer<ma_uint32> pInputFrameCount)>>
A callback for retrieving the number of input frames that are required to output the specified number of output frames. You would only want to implement this when the node performs resampling. This is optional, even for nodes that perform resampling, but it does offer a small reduction in latency as it allows miniaudio to calculate the exact number of input frames to read at a time instead of having to estimate.
getter/setter pair
onProcess Pointer<NativeFunction<Void Function(Pointer<Void> pNode, Pointer<Pointer<Float>> ppFramesIn, Pointer<ma_uint32> pFrameCountIn, Pointer<Pointer<Float>> ppFramesOut, Pointer<ma_uint32> pFrameCountOut)>>
Extended processing callback. This callback is used for effects that process input and output at different rates (i.e. they perform resampling). This is similar to the simple version, only they take two separate frame counts: one for input, and one for output.
getter/setter pair
outputBusCount int
The number of output buses. This is how many sub-buffers will be contained in the ppFramesOut parameters of the callbacks above.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited