flags$1 property
Flags describing characteristics of the node. This is currently just a placeholder for some ideas for later on.
Implementation
@ma_uint32()
external int flags$1;
Flags describing characteristics of the node. This is currently just a placeholder for some ideas for later on.
@ma_uint32()
external int flags$1;