onGetRequiredInputFrameCount property

Pointer<NativeFunction<Int Function(Pointer<Void> pNode, ma_uint32 outputFrameCount, Pointer<ma_uint32> pInputFrameCount)>> onGetRequiredInputFrameCount
getter/setter pair

A callback for retrieving the number of input frames that are required to output the specified number of output frames. You would only want to implement this when the node performs resampling. This is optional, even for nodes that perform resampling, but it does offer a small reduction in latency as it allows miniaudio to calculate the exact number of input frames to read at a time instead of having to estimate.

Implementation

external ffi.Pointer<
  ffi.NativeFunction<
    ffi.Int Function(
      ffi.Pointer<ma_node> pNode,
      ma_uint32 outputFrameCount,
      ffi.Pointer<ma_uint32> pInputFrameCount,
    )
  >
>
onGetRequiredInputFrameCount;