ma_noise class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- ma_noise()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - config ↔ ma_noise_config
-
getter/setter pair
- ds ↔ ma_data_source_base
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lcg ↔ ma_lcg
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ UnnamedUnion$19
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited