ma_resource_manager_config class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allocationCallbacks ma_allocation_callbacks
getter/setter pair
customDecodingBackendCount int
getter/setter pair
decodedChannels int
The decoded channel count to use. Set to 0 (default) to use the file's native channel count.
getter/setter pair
decodedFormat ma_format
no setter
decodedFormatAsInt int
The decoded format to use. Set to ma_format_unknown (default) to use the file's native format.
getter/setter pair
decodedSampleRate int
the decoded sample rate to use. Set to 0 (default) to use the file's native sample rate.
getter/setter pair
flags$1 int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jobQueueCapacity int
The maximum number of jobs that can fit in the queue at a time. Defaults to MA_JOB_TYPE_RESOURCE_MANAGER_QUEUE_CAPACITY. Cannot be zero.
getter/setter pair
jobThreadCount int
Set to 0 if you want to self-manage your job threads. Defaults to 1.
getter/setter pair
jobThreadStackSize int
getter/setter pair
pCustomDecodingBackendUserData Pointer<Void>
getter/setter pair
pLog Pointer<ma_log>
getter/setter pair
ppCustomDecodingBackendVTables Pointer<Pointer<ma_decoding_backend_vtable>>
getter/setter pair
pVFS Pointer<Void>
Can be NULL in which case defaults will be used.
getter/setter pair
resampling ma_resampler_config
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited