ma_resource_manager_data_buffer class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - connector ↔ UnnamedUnion$18
-
Connects this object to the node's data supply.
getter/setter pair
- ds ↔ ma_data_source_base
-
Base data source. A data buffer is a data source.
getter/setter pair
- executionCounter ↔ int
-
For allocating execution orders for jobs.
getter/setter pair
- executionPointer ↔ int
-
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
getter/setter pair
- flags$1 ↔ int
-
The flags that were passed used to initialize the buffer.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnectorInitialized ↔ ma_atomic_bool32
-
Used for asynchronous loading to ensure we don't try to initialize the connector multiple times while waiting for the node to fully load.
getter/setter pair
- isLooping ↔ int
-
Can be read and written by different threads at the same time. Must be used atomically.
getter/setter pair
-
pNode
↔ Pointer<
ma_resource_manager_data_buffer_node> -
The data node. This is reference counted and is what supplies the data.
getter/setter pair
-
pResourceManager
↔ Pointer<
ma_resource_manager> -
A pointer to the resource manager that owns this buffer.
getter/setter pair
- result → ma_result
-
no setter
- resultAsInt ↔ int
-
Keeps track of a result of decoding. Set to MA_BUSY while the buffer is still loading. Set to MA_SUCCESS when loading is finished successfully. Otherwise set to some other code.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seekTargetInPCMFrames ↔ int
-
Only updated by the public API. Never written nor read from the job thread.
getter/setter pair
- seekToCursorOnNextRead ↔ int
-
On the next read we need to seek to the frame cursor.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited