executionPointer property
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
Implementation
@ma_uint32()
external int executionPointer;
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
@ma_uint32()
external int executionPointer;