isLooping property
Can be read and written by different threads at the same time. Must be used atomically.
Implementation
@ma_bool32()
external int isLooping;
Can be read and written by different threads at the same time. Must be used atomically.
@ma_bool32()
external int isLooping;