pNode property
The data node. This is reference counted and is what supplies the data.
Implementation
external ffi.Pointer<ma_resource_manager_data_buffer_node> pNode;
The data node. This is reference counted and is what supplies the data.
external ffi.Pointer<ma_resource_manager_data_buffer_node> pNode;