ma_resource_manager_data_buffer_node class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
data ma_resource_manager_data_supply
getter/setter pair
executionCounter int
For allocating execution orders for jobs.
getter/setter pair
executionPointer int
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hashedName32 int
The hashed name. This is the key.
getter/setter pair
isDataOwnedByResourceManager int
Set to true when the underlying data buffer was allocated the resource manager. Set to false if it is owned by the application (via ma_resource_manager_register_*()).
getter/setter pair
pChildHi Pointer<ma_resource_manager_data_buffer_node>
getter/setter pair
pChildLo Pointer<ma_resource_manager_data_buffer_node>
getter/setter pair
pParent Pointer<ma_resource_manager_data_buffer_node>
getter/setter pair
refCount int
getter/setter pair
result ma_result
no setter
resultAsInt int
Result from asynchronous loading. When loading set to MA_BUSY. When fully loaded set to MA_SUCCESS. When deleting set to MA_UNAVAILABLE.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited