ma_resource_manager_data_source class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
backend UnnamedUnion$17
Must be the first item because we need the first item to be the data source callbacks for the buffer or stream.
getter/setter pair
executionCounter int
For allocating execution orders for jobs.
getter/setter pair
executionPointer int
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
getter/setter pair
flags$1 int
The flags that were passed in to ma_resource_manager_data_source_init().
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited