ma_resource_manager_data_source_flags enum

Inheritance
  • Object
  • Enum
  • ma_resource_manager_data_source_flags
Available extensions

Values

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_STREAM → const ma_resource_manager_data_source_flags

When set, does not load the entire data source in memory. Disk I/O will happen on job threads.

const ma_resource_manager_data_source_flags(1)
MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_DECODE → const ma_resource_manager_data_source_flags

Decode data before storing in memory. When set, decoding is done at the resource manager level rather than the mixing thread. Results in faster mixing, but higher memory usage.

const ma_resource_manager_data_source_flags(2)
MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_ASYNC → const ma_resource_manager_data_source_flags

When set, the resource manager will load the data source asynchronously.

const ma_resource_manager_data_source_flags(4)
MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_WAIT_INIT → const ma_resource_manager_data_source_flags

When set, waits for initialization of the underlying data source before returning from ma_resource_manager_data_source_init().

const ma_resource_manager_data_source_flags(8)
MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_UNKNOWN_LENGTH → const ma_resource_manager_data_source_flags

Gives the resource manager a hint that the length of the data source is unknown and calling ma_data_source_get_length_in_pcm_frames() should be avoided.

const ma_resource_manager_data_source_flags(16)
MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_LOOPING → const ma_resource_manager_data_source_flags

When set, configures the data source to loop by default.

const ma_resource_manager_data_source_flags(32)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ma_resource_manager_data_source_flags>
A constant List of the values in this enum, in order of their declaration.