ma_resource_manager_data_stream class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- absoluteCursor ↔ int
-
The playback cursor, in absolute position starting from the start of the file.
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - currentPageIndex ↔ int
-
Toggles between 0 and 1. Index 0 is the first half of pPageData. Index 1 is the second half. Only ever accessed by the public API. Never accessed by the job thread.
getter/setter pair
- decoder ↔ ma_decoder
-
Used for filling pages with data. This is only ever accessed by the job thread. The public API should never touch this.
getter/setter pair
- ds ↔ ma_data_source_base
-
Base data source. A data stream is a data source.
getter/setter pair
- executionCounter ↔ int
-
For allocating execution orders for jobs.
getter/setter pair
- executionPointer ↔ int
-
For managing the order of execution for asynchronous jobs relating to this object. Incremented as jobs complete processing.
getter/setter pair
- flags$1 ↔ int
-
The flags that were passed used to initialize the stream.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDecoderAtEnd ↔ int
-
Whether or not the decoder has reached the end.
getter/setter pair
- isDecoderInitialized ↔ int
-
Required for determining whether or not the decoder should be uninitialized in MA_JOB_TYPE_RESOURCE_MANAGER_FREE_DATA_STREAM.
getter/setter pair
- isLooping ↔ int
-
Whether or not the stream is looping. It's important to set the looping flag at the data stream level for smooth loop transitions.
getter/setter pair
-
isPageValid
↔ Array<
ma_bool32> -
Booleans to indicate whether or not a page is valid. Set to false by the public API, set to true by the job thread. Set to false as the pages are consumed, true when they are filled.
getter/setter pair
-
pageFrameCount
↔ Array<
ma_bool32> -
The number of valid PCM frames in each page. Used to determine the last valid frame.
getter/setter pair
-
pPageData
↔ Pointer<
Void> -
Buffer containing the decoded data of each page. Allocated once at initialization time.
getter/setter pair
-
pResourceManager
↔ Pointer<
ma_resource_manager> -
A pointer to the resource manager that owns this data stream.
getter/setter pair
- relativeCursor ↔ int
-
The playback cursor, relative to the current page. Only ever accessed by the public API. Never accessed by the job thread.
getter/setter pair
- result → ma_result
-
no setter
- resultAsInt ↔ int
-
Result from asynchronous loading. When loading set to MA_BUSY. When initialized set to MA_SUCCESS. When deleting set to MA_UNAVAILABLE. If an error occurs when loading, set to an error code.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seekCounter ↔ int
-
When 0, no seeking is being performed. When > 0, a seek is being performed and reading should be delayed with MA_BUSY.
getter/setter pair
- totalLengthInPCMFrames ↔ int
-
This is calculated when first loaded by the MA_JOB_TYPE_RESOURCE_MANAGER_LOAD_DATA_STREAM.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited