decoder property
Used for filling pages with data. This is only ever accessed by the job thread. The public API should never touch this.
Implementation
external ma_decoder decoder;
Used for filling pages with data. This is only ever accessed by the job thread. The public API should never touch this.
external ma_decoder decoder;