isDecoderInitialized property
Required for determining whether or not the decoder should be uninitialized in MA_JOB_TYPE_RESOURCE_MANAGER_FREE_DATA_STREAM.
Implementation
@ma_bool32()
external int isDecoderInitialized;
Required for determining whether or not the decoder should be uninitialized in MA_JOB_TYPE_RESOURCE_MANAGER_FREE_DATA_STREAM.
@ma_bool32()
external int isDecoderInitialized;