isLooping property
Whether or not the stream is looping. It's important to set the looping flag at the data stream level for smooth loop transitions.
Implementation
@ma_bool32()
external int isLooping;
Whether or not the stream is looping. It's important to set the looping flag at the data stream level for smooth loop transitions.
@ma_bool32()
external int isLooping;