isPageValid property

  1. @Array.multi<NativeType>([2])
Array<ma_bool32> isPageValid
getter/setter pair

Booleans to indicate whether or not a page is valid. Set to false by the public API, set to true by the job thread. Set to false as the pages are consumed, true when they are filled.

Implementation

@ffi.Array.multi([2])
external ffi.Array<ma_bool32> isPageValid;