totalLengthInPCMFrames property
This is calculated when first loaded by the MA_JOB_TYPE_RESOURCE_MANAGER_LOAD_DATA_STREAM.
Implementation
@ma_uint64()
external int totalLengthInPCMFrames;
This is calculated when first loaded by the MA_JOB_TYPE_RESOURCE_MANAGER_LOAD_DATA_STREAM.
@ma_uint64()
external int totalLengthInPCMFrames;