ma_slot_allocator_group class final

Inheritance
Implemented types
Available extensions

Constructors

ma_slot_allocator_group()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bitfield int
Must be used atomically because the allocation and freeing routines need to make copies of this which must never be optimized away by the compiler.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited