seekTarget property
The PCM frame index to seek to in the mixing thread. Set to (~(ma_uint64)0) to not perform any seeking.
Implementation
@ma_uint64()
external int seekTarget;
The PCM frame index to seek to in the mixing thread. Set to (~(ma_uint64)0) to not perform any seeking.
@ma_uint64()
external int seekTarget;