channelsIn property
Ignored if using a data source as input (the data source's channel count will be used always). Otherwise, setting to 0 will cause the engine's channel count to be used.
Implementation
@ma_uint32()
external int channelsIn;
Ignored if using a data source as input (the data source's channel count will be used always). Otherwise, setting to 0 will cause the engine's channel count to be used.
@ma_uint32()
external int channelsIn;