endCallback property

ma_sound_end_proc endCallback
getter/setter pair

Fired when the sound reaches the end. Will be fired from the audio thread. Do not restart, uninitialize or otherwise change the state of the sound from here. Instead fire an event or set a variable to indicate to a different thread to change the start of the sound. Will not be fired in response to a scheduled stop with ma_sound_set_stop_time_*().

Implementation

external ma_sound_end_proc endCallback;