volumeSmoothTimeInPCMFrames property
The number of frames to smooth over volume changes. Defaults to 0 in which case no smoothing is used.
Implementation
@ma_uint32()
external int volumeSmoothTimeInPCMFrames;
The number of frames to smooth over volume changes. Defaults to 0 in which case no smoothing is used.
@ma_uint32()
external int volumeSmoothTimeInPCMFrames;