ma_sound_flags enum

Sound flags.

Inheritance
Available extensions

Values

MA_SOUND_FLAG_STREAM → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_STREAM

const ma_sound_flags(1)
MA_SOUND_FLAG_DECODE → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_DECODE

const ma_sound_flags(2)
MA_SOUND_FLAG_ASYNC → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_ASYNC

const ma_sound_flags(4)
MA_SOUND_FLAG_WAIT_INIT → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_WAIT_INIT

const ma_sound_flags(8)
MA_SOUND_FLAG_UNKNOWN_LENGTH → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_UNKNOWN_LENGTH

const ma_sound_flags(16)
MA_SOUND_FLAG_LOOPING → const ma_sound_flags

MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_LOOPING

const ma_sound_flags(32)
MA_SOUND_FLAG_NO_DEFAULT_ATTACHMENT → const ma_sound_flags

Do not attach to the endpoint by default. Useful for when setting up nodes in a complex graph system.

const ma_sound_flags(4096)
MA_SOUND_FLAG_NO_PITCH → const ma_sound_flags

Disable pitch shifting with ma_sound_set_pitch() and ma_sound_group_set_pitch(). This is an optimization.

const ma_sound_flags(8192)
MA_SOUND_FLAG_NO_SPATIALIZATION → const ma_sound_flags

Disable spatialization.

const ma_sound_flags(16384)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ma_sound_flags

Constants

values → const List<ma_sound_flags>
A constant List of the values in this enum, in order of their declaration.