gainSmoothTimeInFrames property

  1. @UnsignedInt()
int gainSmoothTimeInFrames
getter/setter pair

When the gain of a channel changes during spatialization, the transition will be linearly interpolated over this number of frames.

Implementation

@ma_uint32()
external int gainSmoothTimeInFrames;