ma_splitter_node_config class final

Splitter Node. 1 input, many outputs. Used for splitting/copying a stream so it can be as input into two separate output nodes.

Inheritance
Implemented types
Available extensions

Constructors

ma_splitter_node_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
channels int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nodeConfig ma_node_config
getter/setter pair
outputBusCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited