ma_standard_channel_map enum

Inheritance
Available extensions

Values

ma_standard_channel_map_microsoft → const ma_standard_channel_map
const ma_standard_channel_map(0)
ma_standard_channel_map_alsa → const ma_standard_channel_map
const ma_standard_channel_map(1)
ma_standard_channel_map_rfc3551 → const ma_standard_channel_map

Based off AIFF.

const ma_standard_channel_map(2)
ma_standard_channel_map_flac → const ma_standard_channel_map
const ma_standard_channel_map(3)
ma_standard_channel_map_vorbis → const ma_standard_channel_map
const ma_standard_channel_map(4)
ma_standard_channel_map_sound4 → const ma_standard_channel_map

FreeBSD's sound(4).

const ma_standard_channel_map(5)
ma_standard_channel_map_sndio → const ma_standard_channel_map

www.sndio.org/tips.html

const ma_standard_channel_map(6)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) ma_standard_channel_map

Constants

ma_standard_channel_map_default → const ma_standard_channel_map
ma_standard_channel_map_webaudio → const ma_standard_channel_map
https://webaudio.github.io/web-audio-api/#ChannelOrdering. Only 1, 2, 4 and 6 channels are defined, but can fill in the gaps with logical assumptions.
values → const List<ma_standard_channel_map>
A constant List of the values in this enum, in order of their declaration.