ma_vfs_callbacks class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
onClose
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pUserData, Pointer<Void> pBackend)> -
getter/setter pair
-
onInfo
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, ma_vfs_file file, Pointer<ma_file_info> pInfo)> -
getter/setter pair
-
onOpen
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, Pointer<Char> pFilePath, ma_uint32 openMode, Pointer<Pointer< pFile)>Void> > -
getter/setter pair
-
onOpenW
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, Pointer<WChar> pFilePath, ma_uint32 openMode, Pointer<Pointer< pFile)>Void> > -
getter/setter pair
-
onRead
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, ma_vfs_file file, Pointer<Void> pDst, Size sizeInBytes, Pointer<Size> pBytesRead)> -
getter/setter pair
-
onSeek
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, ma_vfs_file file, ma_int64 offset, UnsignedInt origin)> -
getter/setter pair
-
onTell
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, ma_vfs_file file, Pointer<ma_int64> pCursor)> -
getter/setter pair
-
onWrite
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> pVFS, ma_vfs_file file, Pointer<Void> pDst, Size sizeInBytes, Pointer<Size> pBytesRead)> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited