mz_error function
Returns a string description of the specified error code, or NULL if the error code is invalid.
Implementation
@ffi.Native<ffi.Pointer<ffi.Char> Function(ffi.Int)>()
external ffi.Pointer<ffi.Char> mz_error(int err);
Returns a string description of the specified error code, or NULL if the error code is invalid.
@ffi.Native<ffi.Pointer<ffi.Char> Function(ffi.Int)>()
external ffi.Pointer<ffi.Char> mz_error(int err);