mz_inflateInit2 function
- @Native<Int Function(mz_streamp, Int)>(mz_streamp, ffi.Int)>()
- mz_streamp pStream,
- int window_bits
mz_inflateInit2() is like mz_inflateInit() with an additional option that controls the window size and whether or not the stream has been wrapped with a zlib header/footer: / / window_bits must be MZ_DEFAULT_WINDOW_BITS (to parse zlib header/footer) or -MZ_DEFAULT_WINDOW_BITS (raw deflate).
Implementation
@ffi.Native<ffi.Int Function(mz_streamp, ffi.Int)>()
external int mz_inflateInit2(mz_streamp pStream, int window_bits);