mz_stream_s class final

Compression/decompression stream struct.

Inheritance
Implemented types
Available extensions

Constructors

mz_stream_s()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
adler int
adler32 of the source or uncompressed data
getter/setter pair
avail_in int
number of bytes available at next_in
getter/setter pair
avail_out int
number of bytes that can be written to next_out
getter/setter pair
data_type int
data_type (unused)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
msg Pointer<Char>
error msg (unused)
getter/setter pair
next_in Pointer<ma_uint8>
pointer to next byte to read
getter/setter pair
next_out Pointer<ma_uint8>
pointer to next byte to write
getter/setter pair
opaque Pointer<Void>
heap alloc function user pointer
getter/setter pair
reserved int
not used
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Pointer<mz_internal_state>
internal state, allocated by zalloc/zfree
getter/setter pair
total_in int
total number of bytes consumed so far
getter/setter pair
total_out int
total number of bytes produced so far
getter/setter pair
zalloc mz_alloc_func
optional heap allocation function (defaults to malloc)
getter/setter pair
zfree mz_free_func
optional heap free function (defaults to free)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited