mz_zip_archive class final

Inheritance
Implemented types
Available extensions

Constructors

mz_zip_archive()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
m_archive_size int
getter/setter pair
m_central_directory_file_ofs int
getter/setter pair
m_file_offset_alignment int
getter/setter pair
m_last_error mz_zip_error
no setter
m_last_errorAsInt int
getter/setter pair
m_pAlloc mz_alloc_func
getter/setter pair
m_pAlloc_opaque Pointer<Void>
getter/setter pair
m_pFree mz_free_func
getter/setter pair
m_pIO_opaque Pointer<Void>
getter/setter pair
m_pNeeds_keepalive Pointer<NativeFunction<mz_file_needs_keepaliveFunction>>
getter/setter pair
m_pRead mz_file_read_func
getter/setter pair
m_pRealloc mz_realloc_func
getter/setter pair
m_pState Pointer<mz_zip_internal_state>
getter/setter pair
m_pWrite mz_file_read_func
getter/setter pair
m_total_files int
We only support up to UINT32_MAX files in zip64 mode.
getter/setter pair
m_zip_mode mz_zip_mode
no setter
m_zip_modeAsInt int
getter/setter pair
m_zip_type mz_zip_type
no setter
m_zip_typeAsInt int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited