mz_zip_reader_extract_to_file function
Extracts a archive file to a disk file and sets its last accessed and modified times. / / This function only extracts files, not archive directory records.
Implementation
@ffi.Native<
mz_bool Function(
ffi.Pointer<mz_zip_archive>,
mz_uint,
ffi.Pointer<ffi.Char>,
mz_uint,
)
>()
external int mz_zip_reader_extract_to_file(
ffi.Pointer<mz_zip_archive> pZip,
int file_index,
ffi.Pointer<ffi.Char> pDst_filename,
int flags$1,
);