mz_zip_reader_init_file function

  1. @Native<mz_bool Function(Pointer<mz_zip_archive>, Pointer<Char>, mz_uint32)>(ffi.Pointer<mz_zip_archive>, ffi.Pointer<ffi.Char>, mz_uint32)>()
int mz_zip_reader_init_file(
  1. Pointer<mz_zip_archive> pZip,
  2. Pointer<Char> pFilename,
  3. int flags$1
)

Read a archive from a disk file. / / file_start_ofs is the file offset where the archive actually begins, or 0. / / actual_archive_size is the true total size of the archive, which may be smaller than the file's actual size on disk. If zero the entire file is treated as the archive.

Implementation

@ffi.Native<
  mz_bool Function(
    ffi.Pointer<mz_zip_archive>,
    ffi.Pointer<ffi.Char>,
    mz_uint32,
  )
>()
external int mz_zip_reader_init_file(
  ffi.Pointer<mz_zip_archive> pZip,
  ffi.Pointer<ffi.Char> pFilename,
  int flags$1,
);