mz_zip_validate_file function
This function compares the archive's local headers, the optional local zip64 extended information block, and the optional descriptor following the compressed data vs. the data in the central directory. / / It also validates that each file can be successfully uncompressed unless the MZ_ZIP_FLAG_VALIDATE_HEADERS_ONLY is specified.
Implementation
@ffi.Native<mz_bool Function(ffi.Pointer<mz_zip_archive>, mz_uint, mz_uint)>()
external int mz_zip_validate_file(
ffi.Pointer<mz_zip_archive> pZip,
int file_index,
int flags$1,
);