mz_zip_writer_end function

  1. @Native<mz_bool Function(Pointer<mz_zip_archive>)>(ffi.Pointer<mz_zip_archive>)>()
int mz_zip_writer_end(
  1. Pointer<mz_zip_archive> pZip
)

Ends archive writing, freeing all allocations, and closing the output file if mz_zip_writer_init_file() was used. / / Note for the archive to be valid, it must have been finalized before ending (this function will not do it for you).

Implementation

@ffi.Native<mz_bool Function(ffi.Pointer<mz_zip_archive>)>()
external int mz_zip_writer_end(ffi.Pointer<mz_zip_archive> pZip);