stb_c_lexer_get_token function

  1. @Native<Int Function(Pointer<stb_lexer>)>(ffi.Pointer<stb_lexer>)>()
int stb_c_lexer_get_token(
  1. Pointer<stb_lexer> lexer
)

this function initialize the 'lexer' structure Input:

  • input_stream points to the file to parse, loaded into memory
  • input_stream_end points to the end of the file, or NULL if you use 0-for-EOF
  • string_store is storage the lexer can use for storing parsed strings and identifiers
  • store_length is the length of that storage

Implementation

@ffi.Native<ffi.Int Function(ffi.Pointer<stb_lexer>)>()
external int stb_c_lexer_get_token(ffi.Pointer<stb_lexer> lexer);