stb_lexer class final

Inheritance
Implemented types
Available extensions

Constructors

stb_lexer()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
eof Pointer<Char>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
input_stream Pointer<Char>
lexer variables
getter/setter pair
int_number int
getter/setter pair
parse_point Pointer<Char>
getter/setter pair
real_number double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string Pointer<Char>
getter/setter pair
string_len int
getter/setter pair
string_storage Pointer<Char>
getter/setter pair
string_storage_len int
getter/setter pair
token int
lexer token variables
getter/setter pair
where_firstchar Pointer<Char>
lexer parse location for error messages
getter/setter pair
where_lastchar Pointer<Char>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited