stbcc_get_unique_id function

  1. @Native<UnsignedInt Function(Pointer<stbcc_grid>, Int, Int)>(ffi.Pointer<stbcc_grid>, ffi.Int, ffi.Int)>()
int stbcc_get_unique_id(
  1. Pointer<stbcc_grid> g,
  2. int x,
  3. int y
)

get a unique id for the connected component this is in; it's not necessarily small, you'll need a hash table or something to remap it (or just use

Implementation

@ffi.Native<
  ffi.UnsignedInt Function(ffi.Pointer<stbcc_grid>, ffi.Int, ffi.Int)
>()
external int stbcc_get_unique_id(ffi.Pointer<stbcc_grid> g, int x, int y);