stbds_hash_bytes function

  1. @Native<Size Function(Pointer<Void>, Size, Size)>(ffi.Pointer<ffi.Void>, ffi.Size, ffi.Size)>()
int stbds_hash_bytes(
  1. Pointer<Void> p,
  2. int len,
  3. int seed
)

these are the hash functions used internally if you want to test them or use them for other purposes

Implementation

@ffi.Native<ffi.Size Function(ffi.Pointer<ffi.Void>, ffi.Size, ffi.Size)>()
external int stbds_hash_bytes(ffi.Pointer<ffi.Void> p, int len, int seed);