stbds_rand_seed function
for security against attackers, seed the library with a random number, at least time() but stronger is better
Implementation
@ffi.Native<ffi.Void Function(ffi.Size)>()
external void stbds_rand_seed(int seed);
for security against attackers, seed the library with a random number, at least time() but stronger is better
@ffi.Native<ffi.Void Function(ffi.Size)>()
external void stbds_rand_seed(int seed);