stbhw_get_last_error function
returns description of last error produced by any function (not thread-safe)
Implementation
@ffi.Native<ffi.Pointer<ffi.Char> Function()>()
external ffi.Pointer<ffi.Char> stbhw_get_last_error();
returns description of last error produced by any function (not thread-safe)
@ffi.Native<ffi.Pointer<ffi.Char> Function()>()
external ffi.Pointer<ffi.Char> stbhw_get_last_error();