stbhw_tileset class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
h_tiles
↔ Pointer<
Pointer< stbhw_tile> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- is_corner ↔ int
-
getter/setter pair
- max_h_tiles ↔ int
-
getter/setter pair
- max_v_tiles ↔ int
-
getter/setter pair
-
num_color
↔ Array<
Int> -
number of colors for each of 6 edge types or 4 corner types
getter/setter pair
- num_h_tiles ↔ int
-
getter/setter pair
- num_v_tiles ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short_side_len ↔ int
-
getter/setter pair
-
v_tiles
↔ Pointer<
Pointer< stbhw_tile> > -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited