eof property
returns nonzero if we are at end of file/data
Implementation
external ffi.Pointer<
ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Void> user)>
>
eof;
returns nonzero if we are at end of file/data
external ffi.Pointer<
ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Void> user)>
>
eof;