stbir_pixel_layout enum

stbir_pixel_layout specifies: number of channels order of channels whether color is premultiplied by alpha for back compatibility, you can cast the old channel count to an stbir_pixel_layout

Inheritance
Available extensions

Values

STBIR_1CHANNEL → const stbir_pixel_layout
const stbir_pixel_layout(1)
STBIR_2CHANNEL → const stbir_pixel_layout
const stbir_pixel_layout(2)
STBIR_RGB → const stbir_pixel_layout

3-chan, with order specified (for channel flipping)

const stbir_pixel_layout(3)
STBIR_BGR → const stbir_pixel_layout

3-chan, with order specified (for channel flipping)

const stbir_pixel_layout(0)
STBIR_4CHANNEL → const stbir_pixel_layout
const stbir_pixel_layout(5)
STBIR_RGBA → const stbir_pixel_layout

alpha formats, where alpha is NOT premultiplied into color channels

const stbir_pixel_layout(4)
STBIR_BGRA → const stbir_pixel_layout
const stbir_pixel_layout(6)
STBIR_ARGB → const stbir_pixel_layout
const stbir_pixel_layout(7)
STBIR_ABGR → const stbir_pixel_layout
const stbir_pixel_layout(8)
STBIR_RA → const stbir_pixel_layout
const stbir_pixel_layout(9)
STBIR_AR → const stbir_pixel_layout
const stbir_pixel_layout(10)
STBIR_RGBA_PM → const stbir_pixel_layout

alpha formats, where alpha is premultiplied into color channels

const stbir_pixel_layout(11)
STBIR_BGRA_PM → const stbir_pixel_layout
const stbir_pixel_layout(12)
STBIR_ARGB_PM → const stbir_pixel_layout
const stbir_pixel_layout(13)
STBIR_ABGR_PM → const stbir_pixel_layout
const stbir_pixel_layout(14)
STBIR_RA_PM → const stbir_pixel_layout
const stbir_pixel_layout(15)
STBIR_AR_PM → const stbir_pixel_layout
const stbir_pixel_layout(16)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) stbir_pixel_layout

Constants

STBIR_ABGR_NO_AW → const stbir_pixel_layout
for some folks).
STBIR_AR_NO_AW → const stbir_pixel_layout
STBIR_ARGB_NO_AW → const stbir_pixel_layout
no alpha weighting). These names just make it more clear
STBIR_BGRA_NO_AW → const stbir_pixel_layout
these are just synonyms for the _PM flags (which also do
STBIR_RA_NO_AW → const stbir_pixel_layout
STBIR_RGBA_NO_AW → const stbir_pixel_layout
alpha formats, where NO alpha weighting is applied at all!
values → const List<stbir_pixel_layout>
A constant List of the values in this enum, in order of their declaration.