toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  if (this == STBIR_RGBA_PM)
    return "stbir_pixel_layout.STBIR_RGBA_PM, stbir_pixel_layout.STBIR_RGBA_NO_AW";
  if (this == STBIR_BGRA_PM)
    return "stbir_pixel_layout.STBIR_BGRA_PM, stbir_pixel_layout.STBIR_BGRA_NO_AW";
  if (this == STBIR_ARGB_PM)
    return "stbir_pixel_layout.STBIR_ARGB_PM, stbir_pixel_layout.STBIR_ARGB_NO_AW";
  if (this == STBIR_ABGR_PM)
    return "stbir_pixel_layout.STBIR_ABGR_PM, stbir_pixel_layout.STBIR_ABGR_NO_AW";
  if (this == STBIR_RA_PM)
    return "stbir_pixel_layout.STBIR_RA_PM, stbir_pixel_layout.STBIR_RA_NO_AW";
  if (this == STBIR_AR_PM)
    return "stbir_pixel_layout.STBIR_AR_PM, stbir_pixel_layout.STBIR_AR_NO_AW";
  return super.toString();
}