stbrp_node class final

///////////////////////////////////////////////////////////////////////////

the details of the following structures don't matter to you, but they must be visible so you can handle the memory allocations for them

Inheritance
Implemented types
Available extensions

Constructors

stbrp_node()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
next Pointer<stbrp_node>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
getter/setter pair
y int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited