stbrp_setup_heuristic function

  1. @Native<Void Function(Pointer<stbrp_context>, Int)>(ffi.Pointer<stbrp_context>, ffi.Int)>()
void stbrp_setup_heuristic(
  1. Pointer<stbrp_context> context,
  2. int heuristic
)

Optionally call this function after init but before doing any packing to change the handling of the out-of-temp-memory scenario, described above. If you call init again, this will be reset to the default (false).

Implementation

@ffi.Native<ffi.Void Function(ffi.Pointer<stbrp_context>, ffi.Int)>()
external void stbrp_setup_heuristic(
  ffi.Pointer<stbrp_context> context,
  int heuristic,
);