stbte_action enum
for keyboard, define your own mapping from keys to the following actions. this is totally optional, as all features are accessible with the mouse
Values
- STBTE_tool_select → const stbte_action
-
const stbte_action(0) - STBTE_tool_brush → const stbte_action
-
const stbte_action(1) - STBTE_tool_erase → const stbte_action
-
const stbte_action(2) - STBTE_tool_rectangle → const stbte_action
-
const stbte_action(3) - STBTE_tool_eyedropper → const stbte_action
-
const stbte_action(4) - STBTE_tool_link → const stbte_action
-
const stbte_action(5) - STBTE_act_toggle_grid → const stbte_action
-
const stbte_action(6) - STBTE_act_toggle_links → const stbte_action
-
const stbte_action(7) - STBTE_act_undo → const stbte_action
-
const stbte_action(8) - STBTE_act_redo → const stbte_action
-
const stbte_action(9) - STBTE_act_cut → const stbte_action
-
const stbte_action(10) - STBTE_act_copy → const stbte_action
-
const stbte_action(11) - STBTE_act_paste → const stbte_action
-
const stbte_action(12) - STBTE_scroll_left → const stbte_action
-
const stbte_action(13) - STBTE_scroll_right → const stbte_action
-
const stbte_action(14) - STBTE_scroll_up → const stbte_action
-
const stbte_action(15) - STBTE_scroll_down → const stbte_action
-
const stbte_action(16)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → stbte_action
Constants
-
values
→ const List<
stbte_action> - A constant List of the values in this enum, in order of their declaration.