stbte_set_layername function
call this to set the spacing of map tiles and the spacing of palette tiles. if you rescale your display, call it again (e.g. you can implement map zooming yourself)
Implementation
@ffi.Native<
ffi.Void Function(ffi.Pointer<stbte_tilemap>, ffi.Int, ffi.Pointer<ffi.Char>)
>()
external void stbte_set_layername(
ffi.Pointer<stbte_tilemap> tm,
int layer,
ffi.Pointer<ffi.Char> layername,
);