stbtt_GetGlyphBitmap function
the following functions are equivalent to the above functions, but operate on glyph indices instead of Unicode codepoints (for efficiency)
Implementation
@ffi.Native<
ffi.Pointer<ffi.UnsignedChar> Function(
ffi.Pointer<stbtt_fontinfo>,
ffi.Float,
ffi.Float,
ffi.Int,
ffi.Pointer<ffi.Int>,
ffi.Pointer<ffi.Int>,
ffi.Pointer<ffi.Int>,
ffi.Pointer<ffi.Int>,
)
>()
external ffi.Pointer<ffi.UnsignedChar> stbtt_GetGlyphBitmap(
ffi.Pointer<stbtt_fontinfo> info,
double scale_x,
double scale_y,
int glyph,
ffi.Pointer<ffi.Int> width,
ffi.Pointer<ffi.Int> height,
ffi.Pointer<ffi.Int> xoff,
ffi.Pointer<ffi.Int> yoff,
);