stbtt_GetPackedQuad function

  1. @Native<Void Function(Pointer<stbtt_packedchar>, Int, Int, Int, Pointer<Float>, Pointer<Float>, Pointer<stbtt_aligned_quad>, Int)>(ffi.Pointer<stbtt_packedchar>, ffi.Int, ffi.Int, ffi.Int, ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>, ffi.Pointer<stbtt_aligned_quad>, ffi.Int)>()
void stbtt_GetPackedQuad(
  1. Pointer<stbtt_packedchar> chardata,
  2. int pw,
  3. int ph,
  4. int char_index,
  5. Pointer<Float> xpos,
  6. Pointer<Float> ypos,
  7. Pointer<stbtt_aligned_quad> q,
  8. int align_to_integer,
)

If skip != 0, this tells stb_truetype to skip any codepoints for which there is no corresponding glyph. If skip=0, which is the default, then codepoints without a glyph recived the font's "missing character" glyph, typically an empty box by convention.

Implementation

@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<stbtt_packedchar>,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Pointer<ffi.Float>,
    ffi.Pointer<ffi.Float>,
    ffi.Pointer<stbtt_aligned_quad>,
    ffi.Int,
  )
>()
external void stbtt_GetPackedQuad(
  ffi.Pointer<stbtt_packedchar> chardata,
  int pw,
  int ph,
  int char_index,
  ffi.Pointer<ffi.Float> xpos,
  ffi.Pointer<ffi.Float> ypos,
  ffi.Pointer<stbtt_aligned_quad> q,
  int align_to_integer,
);