stbtt_MakeCodepointBitmapSubpixel function
the same as stbtt_GetCodepointBitmap, but you pass in storage for the bitmap in the form of 'output', with row spacing of 'out_stride' bytes. the bitmap is clipped to out_w/out_h bytes. Call stbtt_GetCodepointBitmapBox to get the width and height and positioning info for it first.
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbtt_fontinfo>,
ffi.Pointer<ffi.UnsignedChar>,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Float,
ffi.Float,
ffi.Float,
ffi.Float,
ffi.Int,
)
>()
external void stbtt_MakeCodepointBitmapSubpixel(
ffi.Pointer<stbtt_fontinfo> info,
ffi.Pointer<ffi.UnsignedChar> output,
int out_w,
int out_h,
int out_stride,
double scale_x,
double scale_y,
double shift_x,
double shift_y,
int codepoint,
);