stbtt_PackEnd function

  1. @Native<Void Function(Pointer<stbtt_pack_context>)>(ffi.Pointer<stbtt_pack_context>)>()
void stbtt_PackEnd(
  1. Pointer<stbtt_pack_context> spc
)

Initializes a packing context stored in the passed-in stbtt_pack_context. Future calls using this context will pack characters into the bitmap passed in here: a 1-channel bitmap that is width * height. stride_in_bytes is the distance from one row to the next (or 0 to mean they are packed tightly together). "padding" is the amount of padding to leave between each character (normally you want '1' for bitmaps you'll use as textures with bilinear filtering).

Returns 0 on failure, 1 on success.

Implementation

@ffi.Native<ffi.Void Function(ffi.Pointer<stbtt_pack_context>)>()
external void stbtt_PackEnd(ffi.Pointer<stbtt_pack_context> spc);