stbtt_PackSetOversampling function

  1. @Native<Void Function(Pointer<stbtt_pack_context>, UnsignedInt, UnsignedInt)>(ffi.Pointer<stbtt_pack_context>, ffi.UnsignedInt, ffi.UnsignedInt)>()
void stbtt_PackSetOversampling(
  1. Pointer<stbtt_pack_context> spc,
  2. int h_oversample,
  3. int v_oversample
)

Creates character bitmaps from multiple ranges of characters stored in ranges. This will usually create a better-packed bitmap than multiple calls to stbtt_PackFontRange. Note that you can call this multiple times within a single PackBegin/PackEnd.

Implementation

@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<stbtt_pack_context>,
    ffi.UnsignedInt,
    ffi.UnsignedInt,
  )
>()
external void stbtt_PackSetOversampling(
  ffi.Pointer<stbtt_pack_context> spc,
  int h_oversample,
  int v_oversample,
);