stbtt_bakedchar class final
///////////////////////////////////////////////////////////////////////////
TEXTURE BAKING API
If you use this API, you only have to call two functions ever.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x0 ↔ int
-
coordinates of bbox in bitmap
getter/setter pair
- x1 ↔ int
-
getter/setter pair
- xadvance ↔ double
-
getter/setter pair
- xoff ↔ double
-
getter/setter pair
- y0 ↔ int
-
getter/setter pair
- y1 ↔ int
-
getter/setter pair
- yoff ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited