stbtt_pack_range class final
Creates character bitmaps from the font_index'th font found in fontdata (use font_index=0 if you don't know what that is). It creates num_chars_in_range bitmaps for characters with unicode values starting at first_unicode_char_in_range and increasing. Data for how to render them is stored in chardata_for_range; pass these to stbtt_GetPackedQuad to get back renderable quads.
font_size is the full height of the character from ascender to descender, as computed by stbtt_ScaleForPixelHeight. To use a point size as computed by stbtt_ScaleForMappingEmToPixels, wrap the point size in STBTT_POINT_SIZE() and pass that result as 'font_size': ..., 20 , ... // font max minus min y is 20 pixels tall ..., STBTT_POINT_SIZE(20), ... // 'M' is 20 pixels tall
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
array_of_unicode_codepoints
↔ Pointer<
Int> -
if non-zero, then this is an array of unicode codepoints
getter/setter pair
-
chardata_for_range
↔ Pointer<
stbtt_packedchar> -
output
getter/setter pair
- first_unicode_codepoint_in_range ↔ int
-
if non-zero, then the chars are continuous, and this is the first codepoint
getter/setter pair
- font_size ↔ double
-
getter/setter pair
- h_oversample ↔ int
-
don't set these, they're used internally
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- num_chars ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- v_oversample ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited