stbtt_packedchar class final

///////////////////////////////////////////////////////////////////////////

NEW TEXTURE BAKING API

This provides options for packing multiple fonts into one atlas, not perfectly but better than nothing.

Inheritance
Implemented types
Available extensions

Constructors

stbtt_packedchar()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x0 int
coordinates of bbox in bitmap
getter/setter pair
x1 int
getter/setter pair
xadvance double
getter/setter pair
xoff double
getter/setter pair
xoff2 double
getter/setter pair
y0 int
getter/setter pair
y1 int
getter/setter pair
yoff double
getter/setter pair
yoff2 double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited