stbvox_get_transform function

  1. @Native<Void Function(Pointer<stbvox_mesh_maker>, Pointer<Pointer<Float>>)>(ffi.Pointer<stbvox_mesh_maker>, ffi.Pointer<ffi.Pointer<ffi.Float>>)>()
void stbvox_get_transform(
  1. Pointer<stbvox_mesh_maker> mm,
  2. Pointer<Pointer<Float>> transform
)

Returns the bounds for the mesh in global coordinates. Use this for e.g. frustum culling the mesh. @BUG: this just uses the values from stbvox_set_input_range(), so if you build by appending multiple values, this will be wrong, and you need to set stbvox_set_input_range() to the full size. Someday this will switch to tracking the actual bounds of the mesh, though.

Implementation

@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<stbvox_mesh_maker>,
    ffi.Pointer<ffi.Pointer<ffi.Float>>,
  )
>()
external void stbvox_get_transform(
  ffi.Pointer<stbvox_mesh_maker> mm,
  ffi.Pointer<ffi.Pointer<ffi.Float>> transform,
);