stbvox_init_mesh_maker function
- @Native<Void Function(Pointer<
stbvox_mesh_maker> )>(ffi.Pointer<stbvox_mesh_maker>)>()
///////////////////////////////////////////////////////////////////////////
MESHING
A mesh represents a (typically) small chunk of a larger world. Meshes encode coordinates using small integers, so those coordinates must be relative to some base location. All of the coordinates in the functions below use these relative coordinates unless explicitly stated otherwise.
Input to the meshing step is documented further down
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<stbvox_mesh_maker>)>()
external void stbvox_init_mesh_maker(ffi.Pointer<stbvox_mesh_maker> mm);