rgb property

Pointer<stbvox_rgb> rgb
getter/setter pair

these are mostly 3D maps you use to define your voxel world, using x_stride and y_stride note that for cache efficiency, you want to use the block_foo palettes as much as possible instead

Implementation

external ffi.Pointer<stbvox_rgb> rgb;