selector property

Pointer<ma_uint8> selector
getter/setter pair

Array indexed by blocktype containing the vheight values for the top or bottom face of this block. These will rotate properly if the block is rotated. See discussion of vheight. Encode with STBVOX_MAKE_VHEIGHT(sw_height, se_height, nw_height, ne_height)

Implementation

external ffi.Pointer<ffi.UnsignedChar> selector;