tex2 property

Pointer<ma_uint8> tex2
getter/setter pair

Array indexed by blocktype and face containing the texture id for texture #1. The N/E/S/W face choices can be rotated by one of the rotation selectors; The top & bottom face textures will rotate to match. Note that it only makes sense to use one of block_tex1 or block_tex1_face; this pattern repeats throughout and this notice is not repeated.

Implementation

external ffi.Pointer<ffi.UnsignedChar> tex2;