texlerp_vert3 property
Indexed by 3D coordinates, this defines four values: vertlerp is a lerp value at every vertex of the mesh (using STBVOX_TEXLERP_BASE values). ud is the value to use on up and down faces, from STBVOX_TEXLERP_FACE values ew is the value to use on east and west faces, from STBVOX_TEXLERP_FACE values ns is the value to use on north and south faces, from STBVOX_TEXLERP_FACE values If any of ud, ew, or ns is STBVOX_TEXLERP_FACE_use_vert, then the vertlerp values for the vertices are gathered and used for those faces. Encode with STBVOX_MAKE_TEXLERP(vertlerp,ud,ew,sw)
Implementation
external ffi.Pointer<ffi.UnsignedShort> texlerp_vert3;