stbvox_mesh_maker class final

don't mess with this directly, it's just here so you can declare stbvox_mesh_maker on the stack or as a global

Inheritance
Implemented types
Available extensions

Constructors

stbvox_mesh_maker()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
config_dirty int
getter/setter pair
cube_vertex_offset Array<Array<Int>>
this allows access per-vertex data stored block-centered (like texlerp, ambient)
getter/setter pair
cur_x int
last unprocessed voxel if it splits into multiple buffers
getter/setter pair
cur_y int
getter/setter pair
cur_z int
getter/setter pair
default_mesh int
getter/setter pair
default_tex_scale Array<Array<Float>>
getter/setter pair
full int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
input stbvox_input_description
getter/setter pair
num_mesh_slots int
getter/setter pair
output_buffer Array<Array<Pointer<Char>>>
getter/setter pair
output_cur Array<Array<Pointer<Char>>>
computed from user input
getter/setter pair
output_end Array<Array<Pointer<Char>>>
getter/setter pair
output_len Array<Array<Int>>
getter/setter pair
output_size Array<Array<Int>>
per quad
getter/setter pair
output_step Array<Array<Int>>
per vertex or per face, depending
getter/setter pair
pos_x int
getter/setter pair
pos_y int
getter/setter pair
pos_z int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags int
getter/setter pair
vertex_gather_offset Array<Array<Int>>
getter/setter pair
x0 int
getter/setter pair
x1 int
getter/setter pair
x_stride_in_bytes int
getter/setter pair
y0 int
getter/setter pair
y1 int
getter/setter pair
y_stride_in_bytes int
getter/setter pair
z0 int
getter/setter pair
z1 int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited