stbvox_set_default_mesh function
- @Native<Void Function(Pointer<
stbvox_mesh_maker> , Int)>(ffi.Pointer<stbvox_mesh_maker>, ffi.Int)>()
- Pointer<
stbvox_mesh_maker> mm, - int mesh
Returns how much of a given buffer will get used per quad. This allows you to choose correct relative sizes for each buffer, although the values are fixed based on the configuration you've selected at compile time, and the details are described in stbvox_set_buffer.
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<stbvox_mesh_maker>, ffi.Int)>()
external void stbvox_set_default_mesh(
ffi.Pointer<stbvox_mesh_maker> mm,
int mesh,
);