stbvox_set_input_range function

  1. @Native<Void Function(Pointer<stbvox_mesh_maker>, Int, Int, Int, Int, Int, Int)>(ffi.Pointer<stbvox_mesh_maker>, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Int)>()
void stbvox_set_input_range(
  1. Pointer<stbvox_mesh_maker> mm,
  2. int x0,
  3. int y0,
  4. int z0,
  5. int x1,
  6. int y1,
  7. int z1,
)

This sets the stride between successive elements of the 3D arrays in the stbvox_input_description. Z values are always stored consecutively. (The preferred coordinate system for stbvox is X right, Y forwards, Z up.)

Implementation

@ffi.Native<
  ffi.Void Function(
    ffi.Pointer<stbvox_mesh_maker>,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
    ffi.Int,
  )
>()
external void stbvox_set_input_range(
  ffi.Pointer<stbvox_mesh_maker> mm,
  int x0,
  int y0,
  int z0,
  int x1,
  int y1,
  int z1,
);