tinfl_status enum
Return status.
Values
- TINFL_STATUS_FAILED_CANNOT_MAKE_PROGRESS → const tinfl_status
-
This flags indicates the inflator needs 1 or more input bytes to make forward progress, but the caller is indicating that no more are available. The compressed data / / is probably corrupted. If you call the inflator again with more bytes it'll try to continue processing the input but this is a BAD sign (either the data is corrupted or you called it incorrectly). / / If you call it again with no input you'll just get TINFL_STATUS_FAILED_CANNOT_MAKE_PROGRESS again.
const tinfl_status(-4) - TINFL_STATUS_BAD_PARAM → const tinfl_status
-
This flag indicates that one or more of the input parameters was obviously bogus. (You can try calling it again, but if you get this error the calling code is wrong.)
const tinfl_status(-3) - TINFL_STATUS_ADLER32_MISMATCH → const tinfl_status
-
This flags indicate the inflator is finished but the adler32 check of the uncompressed data didn't match. If you call it again it'll return TINFL_STATUS_DONE.
const tinfl_status(-2) - TINFL_STATUS_FAILED → const tinfl_status
-
This flags indicate the inflator has somehow failed (bad code, corrupted input, etc.). If you call it again without resetting via tinfl_init() it it'll just keep on returning the same status failure code.
const tinfl_status(-1) - TINFL_STATUS_DONE → const tinfl_status
-
This flag indicates the inflator has returned every byte of uncompressed data that it can, has consumed every byte that it needed, has successfully reached the end of the deflate stream, and / / if zlib headers and adler32 checking enabled that it has successfully checked the uncompressed data's adler32. If you call it again you'll just get TINFL_STATUS_DONE over and over again.
const tinfl_status(0) - TINFL_STATUS_NEEDS_MORE_INPUT → const tinfl_status
-
This flag indicates the inflator MUST have more input data (even 1 byte) before it can make any more forward progress, or you need to clear the TINFL_FLAG_HAS_MORE_INPUT / / flag on the next call if you don't have any more source data. If the source data was somehow corrupted it's also possible (but unlikely) for the inflator to keep on demanding input to / / proceed, so be sure to properly set the TINFL_FLAG_HAS_MORE_INPUT flag.
const tinfl_status(1) - TINFL_STATUS_HAS_MORE_OUTPUT → const tinfl_status
-
This flag indicates the inflator definitely has 1 or more bytes of uncompressed data available, but it cannot write this data into the output buffer. / / Note if the source compressed data was corrupted it's possible for the inflator to return a lot of uncompressed data to the caller. I've been assuming you know how much uncompressed data to expect / / (either exact or worst case) and will stop calling the inflator and fail after receiving too much. In pure streaming scenarios where you have no idea how many bytes to expect this may not be possible / / so I may need to add some code to address this.
const tinfl_status(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → tinfl_status
Constants
-
values
→ const List<
tinfl_status> - A constant List of the values in this enum, in order of their declaration.