STB_TexteditState class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cursor ↔ int
-
//////////////////
getter/setter pair
- cursor_at_end_of_line ↔ int
-
not implemented yet
getter/setter pair
- has_preferred_x ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized ↔ int
-
getter/setter pair
- insert_mode ↔ int
-
selection start and end point in characters; if equal, no selection.
note that start may be less than or greater than end (e.g. when
dragging the mouse, start is where the initial click was, and you
can drag in either direction)
getter/setter pair
- padding1 ↔ int
-
getter/setter pair
- padding2 ↔ int
-
getter/setter pair
- padding3 ↔ int
-
getter/setter pair
- preferred_x ↔ double
-
this determines where the cursor up/down tries to seek to along x
getter/setter pair
- row_count_per_page ↔ int
-
each textfield keeps its own insert mode state. to keep an app-wide
insert mode, copy this value in/out of the app state
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- select_end ↔ int
-
getter/setter pair
- select_start ↔ int
-
selection start point
getter/setter pair
- single_line ↔ int
-
getter/setter pair
- undostate ↔ StbUndoState
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited