StbTexteditRow class final
result of layout query
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - baseline_y_delta ↔ double
-
position of baseline relative to previous row's baseline
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- num_chars ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x0 ↔ double
-
starting x location, end x location (allows for align=right, etc)
getter/setter pair
- x1 ↔ double
-
getter/setter pair
- ymax ↔ double
-
getter/setter pair
- ymin ↔ double
-
height of row above and below baseline
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited