UnnamedStruct$22 class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isUsingMMapCapture ↔ int
-
getter/setter pair
- isUsingMMapPlayback ↔ int
-
getter/setter pair
- pollDescriptorCountCapture ↔ int
-
getter/setter pair
- pollDescriptorCountPlayback ↔ int
-
getter/setter pair
-
pPCMCapture
↔ Pointer<
Void> -
snd_pcm_t
getter/setter pair
-
pPCMPlayback
↔ Pointer<
Void> -
snd_pcm_t
getter/setter pair
-
pPollDescriptorsCapture
↔ Pointer<
Void> -
struct pollfd
getter/setter pair
-
pPollDescriptorsPlayback
↔ Pointer<
Void> -
struct pollfd
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wakeupfdCapture ↔ int
-
eventfd for waking up from poll() when the capture device is stopped.
getter/setter pair
- wakeupfdPlayback ↔ int
-
eventfd for waking up from poll() when the playback device is stopped.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited