UnnamedStruct$8 class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
asoundSO
↔ Pointer<
Void> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalDeviceEnumLock ↔ ma_mutex
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snd_card_get_index ↔ ma_proc
-
getter/setter pair
- snd_config_update_free_global ↔ ma_proc
-
getter/setter pair
- snd_device_name_free_hint ↔ ma_proc
-
getter/setter pair
- snd_device_name_get_hint ↔ ma_proc
-
getter/setter pair
- snd_device_name_hint ↔ ma_proc
-
getter/setter pair
- snd_pcm_avail ↔ ma_proc
-
getter/setter pair
- snd_pcm_avail_update ↔ ma_proc
-
getter/setter pair
- snd_pcm_close ↔ ma_proc
-
getter/setter pair
- snd_pcm_drain ↔ ma_proc
-
getter/setter pair
- snd_pcm_drop ↔ ma_proc
-
getter/setter pair
- snd_pcm_format_mask_sizeof ↔ ma_proc
-
getter/setter pair
- snd_pcm_format_mask_test ↔ ma_proc
-
getter/setter pair
- snd_pcm_get_chmap ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_any ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_access ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_buffer_size ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_channels ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_channels_max ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_channels_min ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_format ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_format_mask ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_periods ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_rate ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_rate_max ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_get_rate_min ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_access ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_buffer_size_near ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_channels ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_channels_minmax ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_channels_near ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_format ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_format_first ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_periods_near ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_rate ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_rate_minmax ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_rate_near ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_set_rate_resample ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_sizeof ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_test_channels ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_test_format ↔ ma_proc
-
getter/setter pair
- snd_pcm_hw_params_test_rate ↔ ma_proc
-
getter/setter pair
- snd_pcm_info ↔ ma_proc
-
getter/setter pair
- snd_pcm_info_get_name ↔ ma_proc
-
getter/setter pair
- snd_pcm_info_sizeof ↔ ma_proc
-
getter/setter pair
- snd_pcm_mmap_begin ↔ ma_proc
-
getter/setter pair
- snd_pcm_mmap_commit ↔ ma_proc
-
getter/setter pair
- snd_pcm_nonblock ↔ ma_proc
-
getter/setter pair
- snd_pcm_open ↔ ma_proc
-
getter/setter pair
- snd_pcm_poll_descriptors ↔ ma_proc
-
getter/setter pair
- snd_pcm_poll_descriptors_count ↔ ma_proc
-
getter/setter pair
- snd_pcm_poll_descriptors_revents ↔ ma_proc
-
getter/setter pair
- snd_pcm_prepare ↔ ma_proc
-
getter/setter pair
- snd_pcm_readi ↔ ma_proc
-
getter/setter pair
- snd_pcm_recover ↔ ma_proc
-
getter/setter pair
- snd_pcm_reset ↔ ma_proc
-
getter/setter pair
- snd_pcm_start ↔ ma_proc
-
getter/setter pair
- snd_pcm_state ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_current ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_get_boundary ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_set_avail_min ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_set_start_threshold ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_set_stop_threshold ↔ ma_proc
-
getter/setter pair
- snd_pcm_sw_params_sizeof ↔ ma_proc
-
getter/setter pair
- snd_pcm_wait ↔ ma_proc
-
getter/setter pair
- snd_pcm_writei ↔ ma_proc
-
getter/setter pair
- useVerboseDeviceEnumeration ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited