cJSON_Compare function
- @Native<cJSON_bool Function(Pointer<
cJSON> , Pointer<cJSON> , cJSON_bool)>(ffi.Pointer<cJSON>, ffi.Pointer<cJSON>, cJSON_bool)>()
Duplicate will create a new, identical cJSON item to the one you pass, in new memory that will need to be released. With recurse!=0, it will duplicate any children connected to the item. The item->next and ->prev pointers are always zero on return from Duplicate. / / Recursively compare two cJSON items for equality. If either a or b is NULL or invalid, they will be considered unequal. case_sensitive determines if object keys are treated case sensitive (1) or case insensitive (0)
Implementation
@ffi.Native<
cJSON_bool Function(ffi.Pointer<cJSON>, ffi.Pointer<cJSON>, cJSON_bool)
>()
external int cJSON_Compare(
ffi.Pointer<cJSON> a,
ffi.Pointer<cJSON> b,
int case_sensitive,
);