cJSON_CreateIntArray function
These utilities create an Array of count items. The parameter count cannot be greater than the number of elements in the number array, otherwise array access will be out of bounds.
Implementation
@ffi.Native<ffi.Pointer<cJSON> Function(ffi.Pointer<ffi.Int>, ffi.Int)>()
external ffi.Pointer<cJSON> cJSON_CreateIntArray(
ffi.Pointer<ffi.Int> numbers,
int count,
);