cJSON_Minify function

  1. @Native<Void Function(Pointer<Char>)>(ffi.Pointer<ffi.Char>)>()
void cJSON_Minify(
  1. Pointer<Char> json
)

Minify a strings, remove blank characters(such as ' ', '\t', '\r', '\n') from strings. The input pointer json cannot point to a read-only address area, such as a string constant, but should point to a readable and writable address area.

Implementation

@ffi.Native<ffi.Void Function(ffi.Pointer<ffi.Char>)>()
external void cJSON_Minify(ffi.Pointer<ffi.Char> json);