cJSON_ParseWithOpts function
ParseWithOpts allows you to require (and check) that the JSON is null terminated, and to retrieve the pointer to the final byte parsed. / / If you supply a ptr in return_parse_end and parsing fails, then return_parse_end will contain a pointer to the error so will match cJSON_GetErrorPtr().
Implementation
@ffi.Native<
ffi.Pointer<cJSON> Function(
ffi.Pointer<ffi.Char>,
ffi.Pointer<ffi.Pointer<ffi.Char>>,
cJSON_bool,
)
>()
external ffi.Pointer<cJSON> cJSON_ParseWithOpts(
ffi.Pointer<ffi.Char> value,
ffi.Pointer<ffi.Pointer<ffi.Char>> return_parse_end,
int require_null_terminated,
);