crypto_blake2b_ctx class final

Incremental interface

Inheritance
Implemented types
Available extensions

Constructors

crypto_blake2b_ctx()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hash Array<Uint64>
Do not rely on the size or contents of this type, for they may change without notice.
getter/setter pair
hash_size int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
input Array<Uint64>
getter/setter pair
input_idx int
getter/setter pair
input_offset Array<Uint64>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited