hash property

  1. @Array.multi<NativeType>([8])
Array<Uint64> hash
getter/setter pair

Do not rely on the size or contents of this type, for they may change without notice.

Implementation

@ffi.Array.multi([8])
external ffi.Array<ffi.Uint64> hash;