crypto_poly1305_ctx class final
Incremental interface
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
c
↔ Array<
Uint8> -
chunk of the message
getter/setter pair
- c_idx ↔ int
-
How many bytes are there in the chunk.
getter/setter pair
-
h
↔ Array<
mz_uint> -
accumulated hash
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pad
↔ Array<
mz_uint> -
random number added at the end (from the secret key)
getter/setter pair
-
r
↔ Array<
mz_uint> -
constant multiplier (from the secret key)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited