http_errno enum
Values
- HPE_OK → const http_errno
-
const http_errno(0) - HPE_CB_message_begin → const http_errno
-
const http_errno(1) - HPE_CB_url → const http_errno
-
const http_errno(2) - HPE_CB_header_field → const http_errno
-
const http_errno(3) - HPE_CB_header_value → const http_errno
-
const http_errno(4) - HPE_CB_headers_complete → const http_errno
-
const http_errno(5) - HPE_CB_body → const http_errno
-
const http_errno(6) - HPE_CB_message_complete → const http_errno
-
const http_errno(7) - HPE_CB_status → const http_errno
-
const http_errno(8) - HPE_CB_chunk_header → const http_errno
-
const http_errno(9) - HPE_CB_chunk_complete → const http_errno
-
const http_errno(10) - HPE_INVALID_EOF_STATE → const http_errno
-
const http_errno(11) - HPE_HEADER_OVERFLOW → const http_errno
-
const http_errno(12) - HPE_CLOSED_CONNECTION → const http_errno
-
const http_errno(13) - HPE_INVALID_VERSION → const http_errno
-
const http_errno(14) - HPE_INVALID_STATUS → const http_errno
-
const http_errno(15) - HPE_INVALID_METHOD → const http_errno
-
const http_errno(16) - HPE_INVALID_URL → const http_errno
-
const http_errno(17) - HPE_INVALID_HOST → const http_errno
-
const http_errno(18) - HPE_INVALID_PORT → const http_errno
-
const http_errno(19) - HPE_INVALID_PATH → const http_errno
-
const http_errno(20) - HPE_INVALID_QUERY_STRING → const http_errno
-
const http_errno(21) - HPE_INVALID_FRAGMENT → const http_errno
-
const http_errno(22) - HPE_LF_EXPECTED → const http_errno
-
const http_errno(23) - HPE_INVALID_HEADER_TOKEN → const http_errno
-
const http_errno(24) - HPE_INVALID_CONTENT_LENGTH → const http_errno
-
const http_errno(25) - HPE_UNEXPECTED_CONTENT_LENGTH → const http_errno
-
const http_errno(26) - HPE_INVALID_CHUNK_SIZE → const http_errno
-
const http_errno(27) - HPE_INVALID_CONSTANT → const http_errno
-
const http_errno(28) - HPE_INVALID_INTERNAL_STATE → const http_errno
-
const http_errno(29) - HPE_STRICT → const http_errno
-
const http_errno(30) - HPE_PAUSED → const http_errno
-
const http_errno(31) - HPE_UNKNOWN → const http_errno
-
const http_errno(32) - HPE_INVALID_TRANSFER_ENCODING → const http_errno
-
const http_errno(33)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → http_errno
Constants
-
values
→ const List<
http_errno> - A constant List of the values in this enum, in order of their declaration.