http_parser_url class final
Result structure for http_parser_parse_url().
Callers should index into field_data[] with UF_* values iff field_set has the relevant (1 << UF_*) bit set. As a courtesy to clients (and because we probably have padding left over), we convert any port to a uint16_t.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
field_data
↔ Array<
UnnamedStruct> -
getter/setter pair
- field_set ↔ int
-
Bitmask of (1 << UF_*) values
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- port ↔ int
-
Converted UF_PORT string
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited