http_parser_url_fields enum

Inheritance
Available extensions

Values

UF_SCHEMA → const http_parser_url_fields
const http_parser_url_fields(0)
UF_HOST → const http_parser_url_fields
const http_parser_url_fields(1)
UF_PORT → const http_parser_url_fields
const http_parser_url_fields(2)
UF_PATH → const http_parser_url_fields
const http_parser_url_fields(3)
UF_QUERY → const http_parser_url_fields
const http_parser_url_fields(4)
UF_FRAGMENT → const http_parser_url_fields
const http_parser_url_fields(5)
UF_USERINFO → const http_parser_url_fields
const http_parser_url_fields(6)
UF_MAX → const http_parser_url_fields
const http_parser_url_fields(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) http_parser_url_fields

Constants

values → const List<http_parser_url_fields>
A constant List of the values in this enum, in order of their declaration.