ma_channel_converter_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - calculateLFEFromSpatialChannels ↔ int
-
When an output LFE channel is present, but no input LFE, set to true to set the output LFE to the average of all spatial channels (LR, FR, etc.). Ignored when an input LFE is present.
getter/setter pair
- channelsIn ↔ int
-
getter/setter pair
- channelsOut ↔ int
-
getter/setter pair
- format → ma_format
-
no setter
- formatAsInt ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mixingMode → ma_channel_mix_mode
-
no setter
- mixingModeAsInt ↔ int
-
getter/setter pair
-
pChannelMapIn
↔ Pointer<
ma_uint8> -
getter/setter pair
-
pChannelMapOut
↔ Pointer<
ma_uint8> -
getter/setter pair
-
ppWeights
↔ Pointer<
Pointer< Float> > -
out. Only used when mixingMode is set to ma_channel_mix_mode_custom_weights.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited