ma_channel_map_contains_channel_position function
Helper for determining whether or not a channel is present in the given channel map.
The channel map buffer must have a capacity of at least channels.
Implementation
@ffi.Native<
ma_bool32 Function(ma_uint32, ffi.Pointer<ma_channel>, ma_channel)
>()
external int ma_channel_map_contains_channel_position(
int channels,
ffi.Pointer<ma_channel> pChannelMap,
int channelPosition,
);