ma_channel_map_is_equal function

  1. @Native<ma_bool32 Function(Pointer<ma_uint8>, Pointer<ma_uint8>, ma_uint32)>(ffi.Pointer<ma_channel>, ffi.Pointer<ma_channel>, ma_uint32)>()
int ma_channel_map_is_equal(
  1. Pointer<ma_uint8> pChannelMapA,
  2. Pointer<ma_uint8> pChannelMapB,
  3. int channels
)

Helper for comparing two channel maps for equality.

This assumes the channel count is the same between the two.

Both channels map buffers must have a capacity of at least channels.

Implementation

@ffi.Native<
  ma_bool32 Function(
    ffi.Pointer<ma_channel>,
    ffi.Pointer<ma_channel>,
    ma_uint32,
  )
>()
external int ma_channel_map_is_equal(
  ffi.Pointer<ma_channel> pChannelMapA,
  ffi.Pointer<ma_channel> pChannelMapB,
  int channels,
);