ma_channel_map_to_string function
Generates a string representing the given channel map.
This is for printing and debugging purposes, not serialization/deserialization.
Returns the length of the string, not including the null terminator.
Implementation
@ffi.Native<
ffi.Size Function(
ffi.Pointer<ma_channel>,
ma_uint32,
ffi.Pointer<ffi.Char>,
ffi.Size,
)
>()
external int ma_channel_map_to_string(
ffi.Pointer<ma_channel> pChannelMap,
int channels,
ffi.Pointer<ffi.Char> pBufferOut,
int bufferCap,
);