ma_context_get_log function
- @Native<Pointer<
ma_log> Function(Pointer<ma_context> pContext)>(ffi.Pointer<ma_context>)>()
- Pointer<
ma_context> pContext
Retrieves a pointer to the log object associated with this context.
Remarks
Pass the returned pointer to ma_log_post(), ma_log_postv() or ma_log_postf() to post a log
message.
You can attach your own logging callback to the log with ma_log_register_callback()
Return Value
A pointer to the ma_log object that the context uses to post log messages. If some error occurs,
NULL will be returned.
Implementation
@ffi.Native<ffi.Pointer<ma_log> Function(ffi.Pointer<ma_context>)>()
external ffi.Pointer<ma_log> ma_context_get_log(
ffi.Pointer<ma_context> pContext,
);