ma_engine_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - allocationCallbacks ↔ ma_allocation_callbacks
-
getter/setter pair
- channels ↔ int
-
The number of channels to use when mixing and spatializing. When set to 0, will use the native channel count of the device.
getter/setter pair
- dataCallback ↔ ma_device_data_proc
-
Can be null. Can be used to provide a custom device data callback.
getter/setter pair
- defaultVolumeSmoothTimeInPCMFrames ↔ int
-
Defaults to 0. Controls the default amount of smoothing to apply to volume changes to sounds. High values means more smoothing at the expense of high latency (will take longer to reach the new volume).
getter/setter pair
- gainSmoothTimeInFrames ↔ int
-
The number of frames to interpolate the gain of spatialized sounds across. If set to 0, will use gainSmoothTimeInMilliseconds.
getter/setter pair
- gainSmoothTimeInMilliseconds ↔ int
-
When set to 0, gainSmoothTimeInFrames will be used. If both are set to 0, a default value will be used.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- listenerCount ↔ int
-
Must be between 1 and MA_ENGINE_MAX_LISTENERS.
getter/setter pair
- monoExpansionMode → ma_mono_expansion_mode
-
no setter
- monoExpansionModeAsInt ↔ int
-
Controls how the mono channel should be expanded to other channels when spatialization is disabled on a sound.
getter/setter pair
- noAutoStart ↔ int
-
When set to true, requires an explicit call to ma_engine_start(). This is false by default, meaning the engine will be started automatically in ma_engine_init().
getter/setter pair
- noDevice ↔ int
-
When set to true, don't create a default device. ma_engine_read_pcm_frames() can be called manually to read data.
getter/setter pair
- notificationCallback ↔ ma_device_notification_proc
-
getter/setter pair
- onProcess ↔ ma_engine_process_proc
-
Fired at the end of each call to ma_engine_read_pcm_frames(). For engine's that manage their own internal device (the default configuration), this will be fired from the audio thread, and you do not need to call ma_engine_read_pcm_frames() manually in order to trigger this.
getter/setter pair
-
pContext
↔ Pointer<
ma_context> -
getter/setter pair
-
pDevice
↔ Pointer<
ma_device> -
If set, the caller is responsible for calling ma_engine_data_callback() in the device's data callback.
getter/setter pair
- periodSizeInFrames ↔ int
-
If set to something other than 0, updates will always be exactly this size. The underlying device may be a different size, but from the perspective of the mixer that won't matter.
getter/setter pair
- periodSizeInMilliseconds ↔ int
-
Used if periodSizeInFrames is unset.
getter/setter pair
- pitchResampling ↔ ma_resampler_config
-
The resampling config for the pitch and Doppler effects. You will typically want this to be a fast resampler. For high quality stuff, it's recommended that you pre-resample.
getter/setter pair
-
pLog
↔ Pointer<
ma_log> -
When set to NULL, will use the context's log.
getter/setter pair
-
pPlaybackDeviceID
↔ Pointer<
ma_device_id> -
The ID of the playback device to use with the default listener.
getter/setter pair
-
pProcessUserData
↔ Pointer<
Void> -
User data that's passed into onProcess.
getter/setter pair
- preMixStackSizeInBytes ↔ int
-
A stack is used for internal processing in the node graph. This allows you to configure the size of this stack. Smaller values will reduce the maximum depth of your node graph. You should rarely need to modify this.
getter/setter pair
-
pResourceManager
↔ Pointer<
ma_resource_manager> -
Can be null in which case a resource manager will be created for you.
getter/setter pair
-
pResourceManagerVFS
↔ Pointer<
Void> -
A pointer to a pre-allocated VFS object to use with the resource manager. This is ignored if pResourceManager is not NULL.
getter/setter pair
- resourceManagerResampling ↔ ma_resampler_config
-
The resampling config to use with the resource manager.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
The sample rate. When set to 0 will use the native sample rate of the device.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited