channels property
The number of channels to use when mixing and spatializing. When set to 0, will use the native channel count of the device.
Implementation
@ma_uint32()
external int channels;
The number of channels to use when mixing and spatializing. When set to 0, will use the native channel count of the device.
@ma_uint32()
external int channels;