monoExpansionModeAsInt property

  1. @UnsignedInt()
int monoExpansionModeAsInt
getter/setter pair

Controls how the mono channel should be expanded to other channels when spatialization is disabled on a sound.

Implementation

@ffi.UnsignedInt()
external int monoExpansionModeAsInt;