noAutoStart property
When set to true, requires an explicit call to ma_engine_start(). This is false by default, meaning the engine will be started automatically in ma_engine_init().
Implementation
@ma_bool32()
external int noAutoStart;
When set to true, requires an explicit call to ma_engine_start(). This is false by default, meaning the engine will be started automatically in ma_engine_init().
@ma_bool32()
external int noAutoStart;