ma_engine_node class final

Base node object for both ma_sound and ma_sound_group.

Inheritance
Implemented types
Available extensions

Constructors

ma_engine_node()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
baseNode ma_node_base
Must be the first member for compatibility with the ma_node API.
getter/setter pair
fader ma_fader
getter/setter pair
fadeSettings UnnamedStruct$52
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isPitchDisabled int
When set to true, pitching will be disabled which will allow the resampler to be bypassed to save some computation.
getter/setter pair
isSpatializationDisabled int
Set to false by default. When set to false, will not have spatialisation applied.
getter/setter pair
monoExpansionMode ma_mono_expansion_mode
no setter
monoExpansionModeAsInt int
getter/setter pair
oldDopplerPitch double
For determining whether or not the resampler needs to be updated to take a new doppler pitch into account.
getter/setter pair
oldPitch double
For determining whether or not the resampler needs to be updated to reflect the new pitch. The resampler will be updated on the mixing thread.
getter/setter pair
panner ma_panner
getter/setter pair
pEngine Pointer<ma_engine>
A pointer to the engine. Set based on the value from the config.
getter/setter pair
pinnedListenerIndex int
The index of the listener this node should always use for spatialization. If set to MA_LISTENER_INDEX_CLOSEST the engine will use the closest listener.
getter/setter pair
pitch double
getter/setter pair
resampler ma_resampler
For pitch shift.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
The sample rate of the input data. For sounds backed by a data source, this will be the data source's sample rate. Otherwise it'll be the engine's sample rate.
getter/setter pair
spatializer ma_spatializer
getter/setter pair
volume ma_atomic_float
Defaults to 1.
getter/setter pair
volumeGainer ma_gainer
This will only be used if volumeSmoothTimeInPCMFrames is > 0.
getter/setter pair
volumeSmoothTimeInPCMFrames int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited