isPitchDisabled property

  1. @UnsignedInt()
int isPitchDisabled
getter/setter pair

When set to true, pitching will be disabled which will allow the resampler to be bypassed to save some computation.

Implementation

@ma_bool32()
external int isPitchDisabled;