ma_engine_node_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channelsIn ↔ int
-
getter/setter pair
- channelsOut ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPitchDisabled ↔ int
-
Pitching can be explicitly disabled with MA_SOUND_FLAG_NO_PITCH to optimize processing.
getter/setter pair
- isSpatializationDisabled ↔ int
-
Spatialization can be explicitly disabled with MA_SOUND_FLAG_NO_SPATIALIZATION.
getter/setter pair
- monoExpansionMode → ma_mono_expansion_mode
-
no setter
- monoExpansionModeAsInt ↔ int
-
getter/setter pair
-
pEngine
↔ Pointer<
ma_engine> -
getter/setter pair
- pinnedListenerIndex ↔ int
-
The index of the listener this node should always use for spatialization. If set to MA_LISTENER_INDEX_CLOSEST the engine will use the closest listener.
getter/setter pair
- resampling ↔ ma_resampler_config
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
Only used when the type is set to ma_engine_node_type_sound.
getter/setter pair
- type → ma_engine_node_type
-
no setter
- typeAsInt ↔ int
-
getter/setter pair
- volumeSmoothTimeInPCMFrames ↔ int
-
The number of frames to smooth over volume changes. Defaults to 0 in which case no smoothing is used.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited