ma_fader class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- ma_fader()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - config ↔ ma_fader_config
-
getter/setter pair
- cursorInFrames ↔ int
-
The current time in frames. Incremented by ma_fader_process_pcm_frames(). Signed because it'll be offset by startOffsetInFrames in set_fade_ex().
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lengthInFrames ↔ int
-
The total length of the fade.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volumeBeg ↔ double
-
If volumeBeg and volumeEnd is equal to 1, no fading happens (ma_fader_process_pcm_frames() will run as a passthrough).
getter/setter pair
- volumeEnd ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited