ma_job_queue class final

Inheritance
Implemented types
Available extensions

Constructors

ma_job_queue()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
allocator ma_slot_allocator
getter/setter pair
capacity int
The maximum number of jobs that can fit in the queue at a time. Set by the config.
getter/setter pair
flags$1 int
Flags passed in at initialization time.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
The first item in the list. Required for removing from the top of the list.
getter/setter pair
lock int
getter/setter pair
pJobs Pointer<ma_job>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sem ma_semaphore
Only used when MA_JOB_QUEUE_FLAG_NON_BLOCKING is unset.
getter/setter pair
tail int
The last item in the list. Required for appending to the end of the list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited