ma_log_level enum
Logging Levels
Log levels are only used to give logging callbacks some context as to the severity of a log message so they can do filtering. All log levels will be posted to registered logging callbacks. If you don't want to output a certain log level you can discriminate against the log level in the callback.
MA_LOG_LEVEL_DEBUG Used for debugging. Useful for debug and test builds, but should be disabled in release builds.
MA_LOG_LEVEL_INFO Informational logging. Useful for debugging. This will never be called from within the data callback.
MA_LOG_LEVEL_WARNING Warnings. You should enable this in you development builds and action them when encountered. These logs usually indicate a potential problem or misconfiguration, but still allow you to keep running. This will never be called from within the data callback.
MA_LOG_LEVEL_ERROR Error logging. This will be fired when an operation fails and is subsequently aborted. This can be fired from within the data callback, in which case the device will be stopped. You should always have this log level enabled.
Values
- MA_LOG_LEVEL_DEBUG → const ma_log_level
-
const ma_log_level(4) - MA_LOG_LEVEL_INFO → const ma_log_level
-
const ma_log_level(3) - MA_LOG_LEVEL_WARNING → const ma_log_level
-
const ma_log_level(2) - MA_LOG_LEVEL_ERROR → const ma_log_level
-
const ma_log_level(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → ma_log_level
Constants
-
values
→ const List<
ma_log_level> - A constant List of the values in this enum, in order of their declaration.