stateTimes property
Indexed by ma_node_state. Specifies the time based on the global clock that a node should be considered to be in the relevant state.
Implementation
@ffi.Array.multi([2])
external ffi.Array<ma_uint64> stateTimes;
Indexed by ma_node_state. Specifies the time based on the global clock that a node should be considered to be in the relevant state.
@ffi.Array.multi([2])
external ffi.Array<ma_uint64> stateTimes;