ma_node_config class final

Inheritance
Implemented types
Available extensions

Constructors

ma_node_config()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
initialState ma_node_state
no setter
initialStateAsInt int
Defaults to ma_node_state_started.
getter/setter pair
inputBusCount int
Only used if the vtable specifies an input bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise must be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
getter/setter pair
outputBusCount int
Only used if the vtable specifies an output bus count of MA_NODE_BUS_COUNT_UNKNOWN, otherwise be set to MA_NODE_BUS_COUNT_UNKNOWN (default).
getter/setter pair
pInputChannels Pointer<ma_uint32>
The number of elements are determined by the input bus count as determined by the vtable, or inputBusCount if the vtable specifies MA_NODE_BUS_COUNT_UNKNOWN.
getter/setter pair
pOutputChannels Pointer<ma_uint32>
The number of elements are determined by the output bus count as determined by the vtable, or outputBusCount if the vtable specifies MA_NODE_BUS_COUNT_UNKNOWN.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vtable Pointer<ma_node_vtable>
Should never be null. Initialization of the node will fail if so.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited