pOutputChannels property

Pointer<ma_uint32> pOutputChannels
getter/setter pair

The number of elements are determined by the output bus count as determined by the vtable, or outputBusCount if the vtable specifies MA_NODE_BUS_COUNT_UNKNOWN.

Implementation

external ffi.Pointer<ma_uint32> pOutputChannels;