ma_node_graph class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - base ↔ ma_node_base
-
The node graph itself is a node so it can be connected as an input to different node graph. This has zero inputs and calls ma_node_graph_read_pcm_frames() to generate it's output.
getter/setter pair
- endpoint ↔ ma_node_base
-
Special node that all nodes eventually connect to. Data is read from this node in ma_node_graph_read_pcm_frames().
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReading ↔ int
-
Read and written by multiple threads.
getter/setter pair
-
pPreMixStack
↔ Pointer<
ma_stack> -
Modified only by the audio thread.
getter/setter pair
-
pProcessingCache
↔ Pointer<
Float> -
This will be allocated when processingSizeInFrames is non-zero. This is needed because ma_node_graph_read_pcm_frames() can be called with a variable number of frames, and we may need to do some buffering in situations where the caller requests a frame count that's not a multiple of processingSizeInFrames.
getter/setter pair
- processingCacheFramesRemaining ↔ int
-
getter/setter pair
- processingSizeInFrames ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited