nextCounter property
This is used to determine whether or not the input bus is finding the next node in the list. Used for thread safety when detaching output buses.
Implementation
@ma_uint32()
external int nextCounter;
This is used to determine whether or not the input bus is finding the next node in the list. Used for thread safety when detaching output buses.
@ma_uint32()
external int nextCounter;