ma_node_output_bus class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channels ↔ int
-
The number of channels in the audio stream for this bus.
getter/setter pair
- flags$1 ↔ int
-
Some state flags for tracking the read state of the output buffer. A combination of MA_NODE_OUTPUT_BUS_FLAG_*.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputNodeInputBusIndex ↔ int
-
The index of the input bus on the input. Required for detaching. Will only be used within the spinlock so does not need to be atomic.
getter/setter pair
- isAttached ↔ int
-
This is used to prevent iteration of nodes that are in the middle of being detached. Used for thread safety.
getter/setter pair
- lock ↔ int
-
Unfortunate lock, but significantly simplifies the implementation. Required for thread-safe attaching and detaching.
getter/setter pair
- outputBusIndex ↔ int
-
The index of the output bus on pNode that this output bus represents.
getter/setter pair
-
pInputNode
↔ Pointer<
Void> -
The node that this output bus is attached to. Required for detaching.
getter/setter pair
-
pNext
↔ Pointer<
ma_node_output_bus> -
If null, it's the tail node or detached.
getter/setter pair
-
pNode
↔ Pointer<
Void> -
The node that owns this output bus. The input node. Will be null for dummy head and tail nodes.
getter/setter pair
-
pPrev
↔ Pointer<
ma_node_output_bus> -
If null, it's the head node or detached.
getter/setter pair
- refCount ↔ int
-
Reference count for some thread-safety when detaching.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volume ↔ double
-
Linear.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited