inputNodeInputBusIndex property
The index of the input bus on the input. Required for detaching. Will only be used within the spinlock so does not need to be atomic.
Implementation
@ma_uint8()
external int inputNodeInputBusIndex;
The index of the input bus on the input. Required for detaching. Will only be used within the spinlock so does not need to be atomic.
@ma_uint8()
external int inputNodeInputBusIndex;