onProcess property
Pointer<NativeFunction<Void Function(Pointer<Void> pNode, Pointer<Pointer<Float> > ppFramesIn, Pointer<ma_uint32> pFrameCountIn, Pointer<Pointer<Float> > ppFramesOut, Pointer<ma_uint32> pFrameCountOut)> >
onProcess
getter/setter pair
Extended processing callback. This callback is used for effects that process input and output at different rates (i.e. they perform resampling). This is similar to the simple version, only they take two separate frame counts: one for input, and one for output.
On input, pFrameCountOut is equal to the capacity of the output buffer for each bus, whereas
pFrameCountIn will be equal to the number of PCM frames in each of the buffers in ppFramesIn.
On output, set pFrameCountOut to the number of PCM frames that were actually output and set
pFrameCountIn to the number of input frames that were consumed.
Implementation
external ffi.Pointer<
ffi.NativeFunction<
ffi.Void Function(
ffi.Pointer<ma_node> pNode,
ffi.Pointer<ffi.Pointer<ffi.Float>> ppFramesIn,
ffi.Pointer<ma_uint32> pFrameCountIn,
ffi.Pointer<ffi.Pointer<ffi.Float>> ppFramesOut,
ffi.Pointer<ma_uint32> pFrameCountOut,
)
>
>
onProcess;