backend property
Must be the first item because we need the first item to be the data source callbacks for the buffer or stream.
Implementation
external UnnamedUnion$17 backend;
Must be the first item because we need the first item to be the data source callbacks for the buffer or stream.
external UnnamedUnion$17 backend;