ma_resource_manager_data_source_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - flags$1 ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialSeekPointInPCMFrames ↔ int
-
getter/setter pair
- isLooping ↔ int
-
Deprecated. Use the MA_RESOURCE_MANAGER_DATA_SOURCE_FLAG_LOOPING flag in
flagsinstead.getter/setter pair - loopPointBegInPCMFrames ↔ int
-
getter/setter pair
- loopPointEndInPCMFrames ↔ int
-
getter/setter pair
-
pFilePath
↔ Pointer<
Char> -
getter/setter pair
-
pFilePathW
↔ Pointer<
WChar> -
getter/setter pair
-
pNotifications
↔ Pointer<
ma_resource_manager_pipeline_notifications> -
getter/setter pair
- rangeBegInPCMFrames ↔ int
-
getter/setter pair
- rangeEndInPCMFrames ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited