bitfield property

  1. @UnsignedInt()
int bitfield
getter/setter pair

Must be used atomically because the allocation and freeing routines need to make copies of this which must never be optimized away by the compiler.

Implementation

@ma_uint32()
external int bitfield;