ma_sound_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - channelsIn ↔ int
-
Ignored if using a data source as input (the data source's channel count will be used always). Otherwise, setting to 0 will cause the engine's channel count to be used.
getter/setter pair
- channelsOut ↔ int
-
Set this to 0 (default) to use the engine's channel count. Set to MA_SOUND_SOURCE_CHANNEL_COUNT to use the data source's channel count (only used if using a data source as input).
getter/setter pair
- endCallback ↔ ma_sound_end_proc
-
Fired when the sound reaches the end. Will be fired from the audio thread. Do not restart, uninitialize or otherwise change the state of the sound from here. Instead fire an event or set a variable to indicate to a different thread to change the start of the sound. Will not be fired in response to a scheduled stop with ma_sound_set_stop_time_*().
getter/setter pair
- flags$1 ↔ int
-
A combination of MA_SOUND_FLAG_* flags.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialAttachmentInputBusIndex ↔ int
-
The index of the input bus of pInitialAttachment to attach the sound to.
getter/setter pair
- initialSeekPointInPCMFrames ↔ int
-
Initializes the sound such that it's seeked to this location by default.
getter/setter pair
- initNotifications ↔ ma_resource_manager_pipeline_notifications
-
getter/setter pair
- isLooping ↔ int
-
Deprecated. Use the MA_SOUND_FLAG_LOOPING flag in
flagsinstead.getter/setter pair - loopPointBegInPCMFrames ↔ int
-
getter/setter pair
- loopPointEndInPCMFrames ↔ int
-
getter/setter pair
- monoExpansionMode → ma_mono_expansion_mode
-
no setter
- monoExpansionModeAsInt ↔ int
-
Controls how the mono channel should be expanded to other channels when spatialization is disabled on a sound.
getter/setter pair
-
pDataSource
↔ Pointer<
Void> -
Set this to load from an existing data source.
getter/setter pair
-
pDoneFence
↔ Pointer<
ma_fence> -
Deprecated. Use initNotifications instead. Released when the resource manager has finished decoding the entire sound. Not used with streams.
getter/setter pair
-
pEndCallbackUserData
↔ Pointer<
Void> -
getter/setter pair
-
pFilePath
↔ Pointer<
Char> -
Set this to load from the resource manager.
getter/setter pair
-
pFilePathW
↔ Pointer<
WChar> -
Set this to load from the resource manager.
getter/setter pair
-
pInitialAttachment
↔ Pointer<
Void> -
If set, the sound will be attached to an input of this node. This can be set to a ma_sound. If set to NULL, the sound will be attached directly to the endpoint unless MA_SOUND_FLAG_NO_DEFAULT_ATTACHMENT is set in
flags.getter/setter pair - pitchResampling ↔ ma_resampler_config
-
getter/setter pair
- rangeBegInPCMFrames ↔ int
-
getter/setter pair
- rangeEndInPCMFrames ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volumeSmoothTimeInPCMFrames ↔ int
-
The number of frames to smooth over volume changes. Defaults to 0 in which case no smoothing is used.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited