pInitialAttachment property
If set, the sound will be attached to an input of this node. This can be set to a ma_sound. If set to NULL, the sound will be attached directly to the endpoint unless MA_SOUND_FLAG_NO_DEFAULT_ATTACHMENT is set in flags.
Implementation
external ffi.Pointer<ma_node> pInitialAttachment;