gainSmoothTimeInFrames property
When the gain of a channel changes during spatialization, the transition will be linearly interpolated over this number of frames.
Implementation
@ma_uint32()
external int gainSmoothTimeInFrames;
When the gain of a channel changes during spatialization, the transition will be linearly interpolated over this number of frames.
@ma_uint32()
external int gainSmoothTimeInFrames;