ma_spatializer_config class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - attenuationModel → ma_attenuation_model
-
no setter
- attenuationModelAsInt ↔ int
-
getter/setter pair
- channelsIn ↔ int
-
getter/setter pair
- channelsOut ↔ int
-
getter/setter pair
- coneInnerAngleInRadians ↔ double
-
getter/setter pair
- coneOuterAngleInRadians ↔ double
-
getter/setter pair
- coneOuterGain ↔ double
-
getter/setter pair
- directionalAttenuationFactor ↔ double
-
Set to 0 to disable directional attenuation.
getter/setter pair
- dopplerFactor ↔ double
-
Set to 0 to disable doppler effect.
getter/setter pair
- gainSmoothTimeInFrames ↔ int
-
When the gain of a channel changes during spatialization, the transition will be linearly interpolated over this number of frames.
getter/setter pair
- handedness → ma_handedness
-
no setter
- handednessAsInt ↔ int
-
Defaults to right. Forward is -1 on the Z axis. In a left handed system, forward is +1 on the Z axis.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDistance ↔ double
-
getter/setter pair
- maxGain ↔ double
-
getter/setter pair
- minDistance ↔ double
-
getter/setter pair
- minGain ↔ double
-
getter/setter pair
- minSpatializationChannelGain ↔ double
-
The minimal scaling factor to apply to channel gains when accounting for the direction of the sound relative to the listener. Must be in the range of 0..1. Smaller values means more aggressive directional panning, larger values means more subtle directional panning.
getter/setter pair
-
pChannelMapIn
↔ Pointer<
ma_uint8> -
getter/setter pair
- positioning → ma_positioning
-
no setter
- positioningAsInt ↔ int
-
getter/setter pair
- rolloff ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited