mz_zip_archive_file_stat class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- m_bit_flag ↔ int
-
getter/setter pair
- m_central_dir_ofs ↔ int
-
Byte offset of this entry in the archive's central directory. Note we currently only support up to UINT_MAX or less bytes in the central dir.
getter/setter pair
-
m_comment
↔ Array<
Char> -
Comment field. /
/ Guaranteed to be zero terminated, may be truncated to fit.
getter/setter pair
- m_comment_size ↔ int
-
Size of comment in bytes.
getter/setter pair
- m_comp_size ↔ int
-
File's compressed size.
getter/setter pair
- m_crc32 ↔ int
-
CRC-32 of uncompressed data.
getter/setter pair
- m_external_attr ↔ int
-
getter/setter pair
- m_file_index ↔ int
-
Central directory file index.
getter/setter pair
-
m_filename
↔ Array<
Char> -
Filename. If string ends in '/' it's a subdirectory entry. /
/ Guaranteed to be zero terminated, may be truncated to fit.
getter/setter pair
- m_internal_attr ↔ int
-
Zip internal and external file attributes.
getter/setter pair
- m_is_directory ↔ int
-
MZ_TRUE if the entry appears to be a directory.
getter/setter pair
- m_is_encrypted ↔ int
-
MZ_TRUE if the entry uses encryption/strong encryption (which miniz_zip doesn't support)
getter/setter pair
- m_is_supported ↔ int
-
MZ_TRUE if the file is not encrypted, a patch file, and if it uses a compression method we support.
getter/setter pair
- m_local_header_ofs ↔ int
-
Entry's local header file offset in bytes.
getter/setter pair
- m_method ↔ int
-
getter/setter pair
- m_time ↔ int
-
getter/setter pair
- m_uncomp_size ↔ int
-
File's uncompressed size. Note, I've seen some old archives where directory entries had 512 bytes for their uncompressed sizes, but when you try to unpack them you actually get 0 bytes.
getter/setter pair
- m_version_made_by ↔ int
-
These fields are copied directly from the zip's central dir.
getter/setter pair
- m_version_needed ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited