mz_zip_flags enum

Inheritance
Available extensions

Values

MZ_ZIP_FLAG_CASE_SENSITIVE → const mz_zip_flags
const mz_zip_flags(256)
MZ_ZIP_FLAG_IGNORE_PATH → const mz_zip_flags
const mz_zip_flags(512)
MZ_ZIP_FLAG_COMPRESSED_DATA → const mz_zip_flags
const mz_zip_flags(1024)
MZ_ZIP_FLAG_DO_NOT_SORT_CENTRAL_DIRECTORY → const mz_zip_flags
const mz_zip_flags(2048)
MZ_ZIP_FLAG_VALIDATE_LOCATE_FILE_FLAG → const mz_zip_flags

if enabled, mz_zip_reader_locate_file() will be called on each file as its validated to ensure the func finds the file in the central dir (intended for testing)

const mz_zip_flags(4096)
MZ_ZIP_FLAG_VALIDATE_HEADERS_ONLY → const mz_zip_flags

validate the local headers, but don't decompress the entire file and check the crc32

const mz_zip_flags(8192)
MZ_ZIP_FLAG_WRITE_ZIP64 → const mz_zip_flags

always use the zip64 file format, instead of the original zip file format with automatic switch to zip64. Use as flags parameter with mz_zip_writer_init*_v2

const mz_zip_flags(16384)
MZ_ZIP_FLAG_WRITE_ALLOW_READING → const mz_zip_flags
const mz_zip_flags(32768)
MZ_ZIP_FLAG_ASCII_FILENAME → const mz_zip_flags
const mz_zip_flags(65536)
MZ_ZIP_FLAG_WRITE_HEADER_SET_SIZE → const mz_zip_flags

After adding a compressed file, seek back to local file header and set the correct sizes

const mz_zip_flags(131072)
MZ_ZIP_FLAG_READ_ALLOW_WRITING → const mz_zip_flags
const mz_zip_flags(262144)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) mz_zip_flags

Constants

values → const List<mz_zip_flags>
A constant List of the values in this enum, in order of their declaration.