mz_zip_reader_extract_iter_state class final

Inheritance
Implemented types
Available extensions

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
comp_remaining int
getter/setter pair
cur_file_ofs int
getter/setter pair
file_crc32 int
getter/setter pair
file_stat mz_zip_archive_file_stat
getter/setter pair
flags$1 int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inflator tinfl_decompressor
getter/setter pair
out_blk_remain int
getter/setter pair
out_buf_ofs int
getter/setter pair
pRead_buf Pointer<Void>
getter/setter pair
pWrite_buf Pointer<Void>
getter/setter pair
pZip Pointer<mz_zip_archive>
getter/setter pair
read_buf_avail int
getter/setter pair
read_buf_ofs int
getter/setter pair
read_buf_size int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited