mz_zip_writer_add_mem function
Adds the contents of a memory buffer to an archive. These functions record the current local time into the archive. / / To add a directory entry, call this method with an archive name ending in a forwardslash with an empty buffer. / / level_and_flags - compression level (0-10, see MZ_BEST_SPEED, MZ_BEST_COMPRESSION, etc.) logically OR'd with zero or more mz_zip_flags, or just set to MZ_DEFAULT_COMPRESSION.
Implementation
@ffi.Native<
mz_bool Function(
ffi.Pointer<mz_zip_archive>,
ffi.Pointer<ffi.Char>,
ffi.Pointer<ffi.Void>,
ffi.Size,
mz_uint,
)
>()
external int mz_zip_writer_add_mem(
ffi.Pointer<mz_zip_archive> pZip,
ffi.Pointer<ffi.Char> pArchive_name,
ffi.Pointer<ffi.Void> pBuf,
int buf_size,
int level_and_flags,
);