mz_zip_writer_finalize_archive function

  1. @Native<mz_bool Function(Pointer<mz_zip_archive>)>(ffi.Pointer<mz_zip_archive>)>()
int mz_zip_writer_finalize_archive(
  1. Pointer<mz_zip_archive> pZip
)

Finalizes the archive by writing the central directory records followed by the end of central directory record. / / After an archive is finalized, the only valid call on the mz_zip_archive struct is mz_zip_writer_end(). / / An archive must be manually finalized by calling this function for it to be valid.

Implementation

@ffi.Native<mz_bool Function(ffi.Pointer<mz_zip_archive>)>()
external int mz_zip_writer_finalize_archive(ffi.Pointer<mz_zip_archive> pZip);