stbds_hash_bytes function
these are the hash functions used internally if you want to test them or use them for other purposes
Implementation
@ffi.Native<ffi.Size Function(ffi.Pointer<ffi.Void>, ffi.Size, ffi.Size)>()
external int stbds_hash_bytes(ffi.Pointer<ffi.Void> p, int len, int seed);