stbhw_config class final
when requesting a template, you fill out this data
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
corner_type_color_template
↔ Array<
Array< Int> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- is_corner ↔ int
-
using corner colors or edge colors?
getter/setter pair
-
num_color
↔ Array<
Int> -
see below diagram for meaning of the index to this;
6 values if edge (!is_corner), 4 values if is_corner
legal numbers: 1..8 if edge, 1..4 if is_corner
getter/setter pair
- num_vary_x ↔ int
-
additional number of variations along x axis in the template
getter/setter pair
- num_vary_y ↔ int
-
additional number of variations along y axis in the template
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- short_side_len ↔ int
-
rectangles is 2n x n, n = short_side_len
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited