stbhw_tile class final
///////////////////////////////////
TILESET DATA STRUCTURE
if you use the image-to-tileset system from this file, you don't need to worry about these data structures. but if you want to build/load a tileset yourself, you'll need to fill these out.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
- a ↔ int
-
the edge or vertex constraints, according to diagram below
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - b ↔ int
-
getter/setter pair
- c ↔ int
-
getter/setter pair
- d ↔ int
-
getter/setter pair
- e ↔ int
-
getter/setter pair
- f ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pixels
↔ Array<
UnsignedChar> -
The herringbone wang tile data; it is a bitmap which is either
w=2short_sidelen,h=short_sidelen, or w=short_sidelen,h=2short_sidelen.
it is always RGB, stored row-major, with no padding between rows.
(allocate stbhw_tile structure to be large enough for the pixel data)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited