stbi_io_callbacks class final
load image by filename, open file, or memory buffer
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
eof
↔ Pointer<
NativeFunction< mz_file_needs_keepaliveFunction> > -
returns nonzero if we are at end of file/data
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
read
↔ Pointer<
NativeFunction< Int Function(Pointer< >Void> user, Pointer<Char> data, Int size)> -
fill 'data' with 'size' bytes. return number of bytes actually read
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skip
↔ Pointer<
NativeFunction< Void Function(Pointer< >Void> user, Int n)> -
skip the next 'n' bytes, or 'unget' the last -n bytes if negative
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited