stbir_build_samplers_with_splits function
- @Native<Int Function(Pointer<
STBIR_RESIZE> , Int)>(ffi.Pointer<STBIR_RESIZE>, ffi.Int)>()
- Pointer<
STBIR_RESIZE> resize, - int try_splits
This will build samplers for threading. You can pass in the number of threads you'd like to use (try_splits). It returns the number of splits (threads) that you can call it with. It might be less if the image resize can't be split up that many ways.
Implementation
@ffi.Native<ffi.Int Function(ffi.Pointer<STBIR_RESIZE>, ffi.Int)>()
external int stbir_build_samplers_with_splits(
ffi.Pointer<STBIR_RESIZE> resize,
int try_splits,
);