stbir_edge enum

=============================================================== Medium-complexity API

This extends the easy-to-use API as follows:

  • Can specify the datatype - U8, U8_SRGB, U16, FLOAT, HALF_FLOAT
  • Edge wrap can selected explicitly
  • Filter can be selected explicitly

Inheritance
Available extensions

Values

STBIR_EDGE_CLAMP → const stbir_edge
const stbir_edge(0)
STBIR_EDGE_REFLECT → const stbir_edge
const stbir_edge(1)
STBIR_EDGE_WRAP → const stbir_edge

this edge mode is slower and uses more memory

const stbir_edge(2)
STBIR_EDGE_ZERO → const stbir_edge
const stbir_edge(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) stbir_edge

Constants

values → const List<stbir_edge>
A constant List of the values in this enum, in order of their declaration.