stbir_resize_extended_split function

  1. @Native<Int Function(Pointer<STBIR_RESIZE>, Int, Int)>(ffi.Pointer<STBIR_RESIZE>, ffi.Int, ffi.Int)>()
int stbir_resize_extended_split(
  1. Pointer<STBIR_RESIZE> resize,
  2. int split_start,
  3. int split_count
)

Usually, you will always call stbir_resize_split with split_start as the thread_index and "1" for the split_count. But, if you have a weird situation where you MIGHT want 8 threads, but sometimes only 4 threads, you can use 0,2,4,6 for the split_start's and use "2" for the split_count each time to turn in into a 4 thread resize. (This is unusual).

Implementation

@ffi.Native<ffi.Int Function(ffi.Pointer<STBIR_RESIZE>, ffi.Int, ffi.Int)>()
external int stbir_resize_extended_split(
  ffi.Pointer<STBIR_RESIZE> resize,
  int split_start,
  int split_count,
);