stbrp_context class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
active_head
↔ Pointer<
stbrp_node> -
getter/setter pair
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - align ↔ int
-
getter/setter pair
-
extra
↔ Array<
stbrp_node> -
we allocate two extra nodes so optimal user-node-count is 'width' not 'width+2'
getter/setter pair
-
free_head
↔ Pointer<
stbrp_node> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- heuristic ↔ int
-
getter/setter pair
- init_mode ↔ int
-
getter/setter pair
- num_nodes ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited