stbte_define_tile function
- @Native<Void Function(Pointer<
stbte_tilemap> , UnsignedShort, UnsignedInt, Pointer<Char> )>(ffi.Pointer<stbte_tilemap>, ffi.UnsignedShort, ffi.UnsignedInt, ffi.Pointer<ffi.Char>)>()
create an editable tilemap map_x : dimensions of map horizontally (user can change this in editor), <= STBTE_MAX_TILEMAP_X map_y : dimensions of map vertically (user can change this in editor) <= STBTE_MAX_TILEMAP_Y map_layers : number of layers to use (fixed), <= STBTE_MAX_LAYERS spacing_x : initial horizontal distance between left edges of map tiles in stb_tilemap_editor pixels spacing_y : initial vertical distance between top edges of map tiles in stb_tilemap_editor pixels max_tiles : maximum number of tiles that can defined
If insufficient memory, returns NULL
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbte_tilemap>,
ffi.UnsignedShort,
ffi.UnsignedInt,
ffi.Pointer<ffi.Char>,
)
>()
external void stbte_define_tile(
ffi.Pointer<stbte_tilemap> tm,
int id,
int layermask,
ffi.Pointer<ffi.Char> category,
);