stbte_get_link function
get the property array associated with the tile at x,y. this is an array of floats that is STBTE_MAX_PROPERTIES in length; you have to interpret the slots according to the semantics you've chosen
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbte_tilemap>,
ffi.Int,
ffi.Int,
ffi.Pointer<ffi.Int>,
ffi.Pointer<ffi.Int>,
)
>()
external void stbte_get_link(
ffi.Pointer<stbte_tilemap> tm,
int x,
int y,
ffi.Pointer<ffi.Int> destx,
ffi.Pointer<ffi.Int> desty,
);