stbte_set_display function
void
stbte_set_display()
call this repeatedly for each tile to install the tile definitions into the editable tilemap tm : tilemap created by stbte_create_map id : unique identifier for each tile, 0 <= id < 32768 layermask : bitmask of which layers tile is allowed on: 1 = layer 0, 255 = layers 0..7 (note that onscreen, the editor numbers the layers from 1 not 0) layer 0 is the furthest back, layer 1 is just in front of layer 0, etc category : which category this tile is grouped in
Implementation
@ffi.Native<ffi.Void Function(ffi.Int, ffi.Int, ffi.Int, ffi.Int)>()
external void stbte_set_display(int x0, int y0, int x1, int y1);