stbte_set_tile function
clears the map, including the region outside the defined region, so if the user expands the map, they won't see garbage there
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbte_tilemap>,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Short,
)
>()
external void stbte_set_tile(
ffi.Pointer<stbte_tilemap> tm,
int x,
int y,
int layer,
int tile,
);