stbtt_FreeShape function

  1. @Native<Void Function(Pointer<stbtt_fontinfo>, Pointer<stbtt_vertex>)>(ffi.Pointer<stbtt_fontinfo>, ffi.Pointer<stbtt_vertex>)>()
void stbtt_FreeShape(
  1. Pointer<stbtt_fontinfo> info,
  2. Pointer<stbtt_vertex> vertices
)

returns # of vertices and fills *vertices with the pointer to them these are expressed in "unscaled" coordinates

The shape is a series of contours. Each one starts with a STBTT_moveto, then consists of a series of mixed STBTT_lineto and STBTT_curveto segments. A lineto draws a line from previous endpoint to its x,y; a curveto draws a quadratic bezier from previous endpoint to its x,y, using cx,cy as the bezier control point.

Implementation

@ffi.Native<
  ffi.Void Function(ffi.Pointer<stbtt_fontinfo>, ffi.Pointer<stbtt_vertex>)
>()
external void stbtt_FreeShape(
  ffi.Pointer<stbtt_fontinfo> info,
  ffi.Pointer<stbtt_vertex> vertices,
);