stbtt_GetCodepointKernAdvance function

  1. @Native<Int Function(Pointer<stbtt_fontinfo>, Int, Int)>(ffi.Pointer<stbtt_fontinfo>, ffi.Int, ffi.Int)>()
int stbtt_GetCodepointKernAdvance(
  1. Pointer<stbtt_fontinfo> info,
  2. int ch1,
  3. int ch2
)

leftSideBearing is the offset from the current horizontal position to the left edge of the character advanceWidth is the offset from the current horizontal position to the next horizontal position these are expressed in unscaled coordinates

Implementation

@ffi.Native<ffi.Int Function(ffi.Pointer<stbtt_fontinfo>, ffi.Int, ffi.Int)>()
external int stbtt_GetCodepointKernAdvance(
  ffi.Pointer<stbtt_fontinfo> info,
  int ch1,
  int ch2,
);