stbtt_GetPackedQuad function
If skip != 0, this tells stb_truetype to skip any codepoints for which there is no corresponding glyph. If skip=0, which is the default, then codepoints without a glyph recived the font's "missing character" glyph, typically an empty box by convention.
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbtt_packedchar>,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Pointer<ffi.Float>,
ffi.Pointer<ffi.Float>,
ffi.Pointer<stbtt_aligned_quad>,
ffi.Int,
)
>()
external void stbtt_GetPackedQuad(
ffi.Pointer<stbtt_packedchar> chardata,
int pw,
int ph,
int char_index,
ffi.Pointer<ffi.Float> xpos,
ffi.Pointer<ffi.Float> ypos,
ffi.Pointer<stbtt_aligned_quad> q,
int align_to_integer,
);