stbtt_PackSetSkipMissingCodepoints function
- @Native<Void Function(Pointer<
stbtt_pack_context> , Int)>(ffi.Pointer<stbtt_pack_context>, ffi.Int)>()
- Pointer<
stbtt_pack_context> spc, - int skip
Oversampling a font increases the quality by allowing higher-quality subpixel positioning, and is especially valuable at smaller text sizes.
This function sets the amount of oversampling for all following calls to stbtt_PackFontRange(s) or stbtt_PackFontRangesGatherRects for a given pack context. The default (no oversampling) is achieved by h_oversample=1 and v_oversample=1. The total number of pixels required is h_oversample*v_oversample larger than the default; for example, 2x2 oversampling requires 4x the storage of 1x1. For best results, render oversampled textures with bilinear filtering. Look at the readme in stb/tests/oversample for information about oversampled fonts
To use with PackFontRangesGather etc., you must set it before calls call to PackFontRangesGatherRects.
Implementation
@ffi.Native<ffi.Void Function(ffi.Pointer<stbtt_pack_context>, ffi.Int)>()
external void stbtt_PackSetSkipMissingCodepoints(
ffi.Pointer<stbtt_pack_context> spc,
int skip,
);