stbtt_aligned_quad class final
if return is positive, the first unused row of the bitmap if return is negative, returns the negative of the number of characters that fit if return is 0, no characters fit and no rows were used This uses a very crappy packing.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- s0 ↔ double
-
getter/setter pair
- s1 ↔ double
-
getter/setter pair
- t0 ↔ double
-
getter/setter pair
- t1 ↔ double
-
getter/setter pair
- x0 ↔ double
-
top-left
getter/setter pair
- x1 ↔ double
-
bottom-right
getter/setter pair
- y0 ↔ double
-
getter/setter pair
- y1 ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited