stbtt_fontinfo class final
The following structure is defined publicly so you can declare one on the stack or as a global or etc, but you should treat it as opaque.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - cff ↔ stbtt__buf
-
cff font data
getter/setter pair
- charstrings ↔ stbtt__buf
-
the charstring index
getter/setter pair
-
data
↔ Pointer<
ma_uint8> -
pointer to .ttf file
getter/setter pair
- fdselect ↔ stbtt__buf
-
map from glyph to fontdict
getter/setter pair
- fontdicts ↔ stbtt__buf
-
array of font dicts
getter/setter pair
- fontstart ↔ int
-
offset of start of font
getter/setter pair
- glyf ↔ int
-
getter/setter pair
- gpos ↔ int
-
getter/setter pair
- gsubrs ↔ stbtt__buf
-
global charstring subroutines index
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- head ↔ int
-
getter/setter pair
- hhea ↔ int
-
getter/setter pair
- hmtx ↔ int
-
getter/setter pair
- index_map ↔ int
-
a cmap mapping for our chosen character encoding
getter/setter pair
- indexToLocFormat ↔ int
-
format needed to map from glyph index to glyph
getter/setter pair
- kern ↔ int
-
getter/setter pair
- loca ↔ int
-
table locations as offset from start of .ttf
getter/setter pair
- numGlyphs ↔ int
-
number of glyphs, needed for range checking
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subrs ↔ stbtt__buf
-
private charstring subroutines index
getter/setter pair
- svg ↔ int
-
getter/setter pair
-
userdata
↔ Pointer<
Void> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited