stbtt_pack_context class final
this is an opaque structure that you shouldn't mess with which holds all the context needed from PackBegin to PackEnd.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - h_oversample ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
-
nodes
↔ Pointer<
Void> -
getter/setter pair
-
pack_info
↔ Pointer<
Void> -
getter/setter pair
- padding ↔ int
-
getter/setter pair
-
pixels
↔ Pointer<
ma_uint8> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skip_missing ↔ int
-
getter/setter pair
- stride_in_bytes ↔ int
-
getter/setter pair
-
user_allocator_context
↔ Pointer<
Void> -
getter/setter pair
- v_oversample ↔ int
-
getter/setter pair
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited