overlay_tex2 property
Array indexed by overlay value and face, containing an override value for the texture id for texture #1. If 0, the value defined by blocktype is used.
Implementation
external ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> overlay_tex2;