stbvox_set_input_range function
This sets the stride between successive elements of the 3D arrays in the stbvox_input_description. Z values are always stored consecutively. (The preferred coordinate system for stbvox is X right, Y forwards, Z up.)
Implementation
@ffi.Native<
ffi.Void Function(
ffi.Pointer<stbvox_mesh_maker>,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Int,
ffi.Int,
)
>()
external void stbvox_set_input_range(
ffi.Pointer<stbvox_mesh_maker> mm,
int x0,
int y0,
int z0,
int x1,
int y1,
int z1,
);