stbvox_set_input_stride function

  1. @Native<Void Function(Pointer<stbvox_mesh_maker>, Int, Int)>(ffi.Pointer<stbvox_mesh_maker>, ffi.Int, ffi.Int)>()
void stbvox_set_input_stride(
  1. Pointer<stbvox_mesh_maker> mm,
  2. int x_stride_in_elements,
  3. int y_stride_in_elements
)

This function call returns a pointer to the stbvox_input_description part of stbvox_mesh_maker (which you should otherwise treat as opaque). You zero this structure, then fill out the relevant pointers to the data describing your voxel object/world.

See further documentation at the description of stbvox_input_description below.

Implementation

@ffi.Native<
  ffi.Void Function(ffi.Pointer<stbvox_mesh_maker>, ffi.Int, ffi.Int)
>()
external void stbvox_set_input_stride(
  ffi.Pointer<stbvox_mesh_maker> mm,
  int x_stride_in_elements,
  int y_stride_in_elements,
);