stbvox_uniform_info class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - array_length ↔ int
-
length of the uniform array
getter/setter pair
- bytes_per_element ↔ int
-
the size of each uniform array element (e.g. vec3 = 12 bytes)
getter/setter pair
-
default_value
↔ Pointer<
Float> -
if not NULL, you can use this as the uniform pointer
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
↔ Pointer<
Char> -
name in the shader @TODO use numeric binding
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ int
-
which type of uniform
getter/setter pair
- use_tex_buffer ↔ int
-
if true, then the uniform is a sampler but the data can come from default_value
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited