tdefl_flush enum
Must map to MZ_NO_FLUSH, MZ_SYNC_FLUSH, etc. enums
Values
- TDEFL_NO_FLUSH → const tdefl_flush
-
const tdefl_flush(0) - TDEFL_SYNC_FLUSH → const tdefl_flush
-
const tdefl_flush(2) - TDEFL_FULL_FLUSH → const tdefl_flush
-
const tdefl_flush(3) - TDEFL_FINISH → const tdefl_flush
-
const tdefl_flush(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → tdefl_flush
Constants
-
values
→ const List<
tdefl_flush> - A constant List of the values in this enum, in order of their declaration.