tdefl_status enum
The low-level tdefl functions below may be used directly if the above helper functions aren't flexible enough. The low-level functions don't make any heap allocations, unlike the above helper functions.
Values
- TDEFL_STATUS_BAD_PARAM → const tdefl_status
-
const tdefl_status(-2) - TDEFL_STATUS_PUT_BUF_FAILED → const tdefl_status
-
const tdefl_status(-1) - TDEFL_STATUS_OKAY → const tdefl_status
-
const tdefl_status(0) - TDEFL_STATUS_DONE → const tdefl_status
-
const tdefl_status(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → tdefl_status
Constants
-
values
→ const List<
tdefl_status> - A constant List of the values in this enum, in order of their declaration.