tinfl_put_buf_func_ptr typedef
tinfl_decompress_mem_to_callback() decompresses a block in memory to an internal 32KB buffer, and a user provided callback function will be called to flush the buffer. / / Returns 1 on success or 0 on failure.
Implementation
typedef tinfl_put_buf_func_ptr =
ffi.Pointer<ffi.NativeFunction<tinfl_put_buf_func_ptrFunction>>;